function [ret,x0,str,ts,xts]=bbestime(t,x,u,flag);
%BBESTIME	is the M-file description of the SIMULINK system named BBESTIME.
%	The block-diagram can be displayed by typing: BBESTIME.
%
%	SYS=BBESTIME(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BBESTIME to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BBESTIME with a FLAG of zero:
%	[SIZES]=BBESTIME([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[91,221,1245,882])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'instant_injection*1')
set_param(sys,'Stop time',     'instant_injection*1+6100')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '2')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','n')

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[825,358,945,392])

add_block('built-in/Note',[sys,'/','Drive B'])
set_param([sys,'/','Drive B'],...
		'position',[600,415,605,420])

add_block('built-in/Note',[sys,'/','t - nT'])
set_param([sys,'/','t - nT'],...
		'position',[615,365,620,370])

add_block('built-in/Note',[sys,'/','B(n)'])
set_param([sys,'/','B(n)'],...
		'position',[640,300,645,305])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[735,279,760,466])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'position',[645,372,670,468])


%     Subsystem  'CHAMP MESURE'.

new_system([sys,'/','CHAMP MESURE'])
set_param([sys,'/','CHAMP MESURE'],'Location',[259,223,1178,673])
open_system([sys,'/','CHAMP MESURE'])

add_block('built-in/MATLAB Fcn',[sys,'/',['CHAMP MESURE/Partie',13,'entire n']])
set_param([sys,'/',['CHAMP MESURE/Partie',13,'entire n']],...
		'hide name',0,...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[130,233,190,267])

add_block('built-in/Sum',[sys,'/','CHAMP MESURE/Sum'])
set_param([sys,'/','CHAMP MESURE/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[235,159,255,281])

add_block('built-in/To Workspace',[sys,'/','CHAMP MESURE/To Workspace2'])
set_param([sys,'/','CHAMP MESURE/To Workspace2'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[180,123,245,137])

add_block('built-in/Clock',[sys,'/','CHAMP MESURE/Clock2'])
set_param([sys,'/','CHAMP MESURE/Clock2'],...
		'hide name',0,...
		'position',[40,230,80,270])

add_block('built-in/Inport',[sys,'/','CHAMP MESURE/in_1'])
set_param([sys,'/','CHAMP MESURE/in_1'],...
		'position',[40,80,60,100])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Entre de B(t) //xyz '])
set_param([sys,'/','CHAMP MESURE/Entre de B(t) //xyz '],...
		'position',[90,50,95,55])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[65,190,70,195])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Calcul t-nT'])
set_param([sys,'/','CHAMP MESURE/Calcul t-nT'],...
		'hide name',0,...
		'position',[240,300,245,305])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/t-nT'])
set_param([sys,'/','CHAMP MESURE/t-nT'],...
		'position',[930,355,935,360])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Sortie champ B chapeau'])
set_param([sys,'/','CHAMP MESURE/Sortie champ B chapeau'],...
		'position',[595,50,600,55])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/t - nT'])
set_param([sys,'/','CHAMP MESURE/t - nT'],...
		'position',[310,220,315,225])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[190,70,195,75])

add_block('built-in/Mux',[sys,'/','CHAMP MESURE/Mux1'])
set_param([sys,'/','CHAMP MESURE/Mux1'],...
		'inputs','[3 1]',...
		'position',[420,81,450,114])

add_block('built-in/MATLAB Fcn',[sys,'/',['CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3',...
		'position',[480,83,540,117])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/Partie',13,'entire de',13,'t//T']])
set_param([sys,'/',['CHAMP MESURE/Partie',13,'entire de',13,'t//T']],...
		'position',[150,275,155,280])

add_block('built-in/Outport',[sys,'/','CHAMP MESURE/out_2'])
set_param([sys,'/','CHAMP MESURE/out_2'],...
		'Port','2',...
		'position',[590,290,610,310])

add_block('built-in/Outport',[sys,'/','CHAMP MESURE/out_1'])
set_param([sys,'/','CHAMP MESURE/out_1'],...
		'position',[585,90,605,110])

add_block('built-in/To Workspace',[sys,'/','CHAMP MESURE/To Workspace3'])
set_param([sys,'/','CHAMP MESURE/To Workspace3'],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[585,142,635,158])

add_block('built-in/Relational Operator',[sys,'/',['CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[350,128,375,252])

add_block('built-in/Constant',[sys,'/','CHAMP MESURE/Constant1'])
set_param([sys,'/','CHAMP MESURE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[280,149,315,171])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Sortie de to = t - nT'])
set_param([sys,'/','CHAMP MESURE/Sortie de to = t - nT'],...
		'position',[560,255,565,260])
add_line([sys,'/','CHAMP MESURE'],[260,220;345,220])
add_line([sys,'/','CHAMP MESURE'],[85,250;125,250])
add_line([sys,'/','CHAMP MESURE'],[115,250;115,190;230,190])
add_line([sys,'/','CHAMP MESURE'],[165,190;175,130])
add_line([sys,'/','CHAMP MESURE'],[195,250;230,250])
add_line([sys,'/','CHAMP MESURE'],[65,90;415,90])
add_line([sys,'/','CHAMP MESURE'],[260,220;260,300;585,300])
add_line([sys,'/','CHAMP MESURE'],[455,100;475,100])
add_line([sys,'/','CHAMP MESURE'],[545,100;580,100])
add_line([sys,'/','CHAMP MESURE'],[380,190;405,190;415,105])
add_line([sys,'/','CHAMP MESURE'],[565,100;565,150;580,150])
add_line([sys,'/','CHAMP MESURE'],[320,160;345,160])
set_param([sys,'/','CHAMP MESURE'],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block 'CHAMP MESURE'.

set_param([sys,'/','CHAMP MESURE'],...
		'position',[410,308,545,377])


%     Subsystem  'DERIVEE MESUREE'.

new_system([sys,'/','DERIVEE MESUREE'])
set_param([sys,'/','DERIVEE MESUREE'],'Location',[186,119,924,515])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Entre de dB//dt //xyz '])
set_param([sys,'/','DERIVEE MESUREE/Entre de dB//dt //xyz '],...
		'position',[280,90,285,95])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[350,10,355,15])

add_block('built-in/Inport',[sys,'/','DERIVEE MESUREE/in_1'])
set_param([sys,'/','DERIVEE MESUREE/in_1'],...
		'position',[20,110,40,130])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Sortie B_prime'])
set_param([sys,'/','DERIVEE MESUREE/Sortie B_prime'],...
		'position',[475,150,480,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3',...
		'position',[435,183,495,217])

add_block('built-in/Mux',[sys,'/','DERIVEE MESUREE/Mux1'])
set_param([sys,'/','DERIVEE MESUREE/Mux1'],...
		'inputs','[3 1]',...
		'position',[380,181,410,214])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/t-nT<=Ta'])
set_param([sys,'/','DERIVEE MESUREE/t-nT<=Ta'],...
		'position',[270,265,275,270])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/t-nT'])
set_param([sys,'/','DERIVEE MESUREE/t-nT'],...
		'position',[260,210,265,215])

add_block('built-in/Relational Operator',[sys,'/',['DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[300,143,325,267])

add_block('built-in/Constant',[sys,'/','DERIVEE MESUREE/Constant1'])
set_param([sys,'/','DERIVEE MESUREE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[250,164,285,186])

add_block('built-in/Sum',[sys,'/','DERIVEE MESUREE/Sum'])
set_param([sys,'/','DERIVEE MESUREE/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[215,174,235,296])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[35,290,40,295])

add_block('built-in/Inport',[sys,'/','DERIVEE MESUREE/in_2'])
set_param([sys,'/','DERIVEE MESUREE/in_2'],...
		'Port','2',...
		'position',[30,255,50,275])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Temps'])
set_param([sys,'/','DERIVEE MESUREE/Temps'],...
		'position',[150,180,155,185])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/nT'])
set_param([sys,'/','DERIVEE MESUREE/nT'],...
		'position',[190,240,195,245])

add_block('built-in/To Workspace',[sys,'/','DERIVEE MESUREE/To Workspace4'])
set_param([sys,'/','DERIVEE MESUREE/To Workspace4'],...
		'mat-name','n',...
		'buffer','20000',...
		'position',[325,317,375,333])

add_block('built-in/Gain',[sys,'/','DERIVEE MESUREE/Gain'])
set_param([sys,'/','DERIVEE MESUREE/Gain'],...
		'Gain','1/T',...
		'position',[215,312,240,338])

add_block('built-in/Outport',[sys,'/','DERIVEE MESUREE/out_1'])
set_param([sys,'/','DERIVEE MESUREE/out_1'],...
		'position',[575,190,595,210])

add_block('built-in/MATLAB Fcn',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire n']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire n']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[110,248,170,282])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire de',13,'t//T']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire de',13,'t//T']],...
		'position',[140,320,145,325])

add_block('built-in/To Workspace',[sys,'/','DERIVEE MESUREE/To Workspace5'])
set_param([sys,'/','DERIVEE MESUREE/To Workspace5'],...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[555,243,675,277])
add_line([sys,'/','DERIVEE MESUREE'],[55,265;105,265])
add_line([sys,'/','DERIVEE MESUREE'],[70,265;70,205;210,205])
add_line([sys,'/','DERIVEE MESUREE'],[175,265;210,265])
add_line([sys,'/','DERIVEE MESUREE'],[240,235;295,235])
add_line([sys,'/','DERIVEE MESUREE'],[45,120;355,120;355,190;375,190])
add_line([sys,'/','DERIVEE MESUREE'],[290,175;295,175])
add_line([sys,'/','DERIVEE MESUREE'],[330,205;375,205])
add_line([sys,'/','DERIVEE MESUREE'],[415,200;430,200])
add_line([sys,'/','DERIVEE MESUREE'],[500,200;570,200])
add_line([sys,'/','DERIVEE MESUREE'],[245,325;320,325])
add_line([sys,'/','DERIVEE MESUREE'],[175,265;175,325;210,325])
add_line([sys,'/','DERIVEE MESUREE'],[520,200;520,260;550,260])
set_param([sys,'/','DERIVEE MESUREE'],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block 'DERIVEE MESUREE'.

set_param([sys,'/','DERIVEE MESUREE'],...
		'position',[415,405,550,485])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'mat-name','champ_reel',...
		'buffer','20000',...
		'position',[410,248,530,282])

add_block('built-in/Note',[sys,'/','Temps'])
set_param([sys,'/','Temps'],...
		'position',[65,300,70,305])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[65,335,85,355])

add_block('built-in/Note',[sys,'/',['Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[190,370,195,375])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Les courbes\n\nchamp pulse linaris\n\nchamp rel',...
		'Mask Dialogue','eval(''plot(temps,champ_pulse,temps,champ_reel);grid;shg'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[870,140,1095,226])


%     Subsystem  'Extras4'.

new_system([sys,'/','Extras4'])
set_param([sys,'/','Extras4'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras4'],...
		'Mask Display','Drive de B pulse\nsimple',...
		'Mask Dialogue','eval(''plot(temps,derb_chapeau);grid;shg'')')


%     Finished composite block 'Extras4'.

set_param([sys,'/','Extras4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[55,125,270,216])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[120,319,275,371])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Diffrence\nchamp rel, champ pulse\nsimple',...
		'Mask Dialogue','eval(''plot(temps(110:length(temps)),champ_reel(110:length(temps),1:3)-champ_pulse(110:length(temps),1:3));grid;gcf'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[870,240,1095,336])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Diffrence\nchamp rel, champ pulse\nsimple',...
		'Mask Dialogue','eval(''plot(temps(110:length(temps)),champ_reel(110:length(temps),1:3)-champ1(110:length(temps),1:3));grid;gcf'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[55,15,280,111])

add_block('built-in/Note',[sys,'/','Calcul t-nT'])
set_param([sys,'/','Calcul t-nT'],...
		'hide name',0,...
		'position',[520,605,525,610])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'mat-name','derBreel',...
		'buffer','20000',...
		'position',[425,523,545,557])

add_block('built-in/Derivative',[sys,'/',['Drive de',13,'B relle']])
set_param([sys,'/',['Drive de',13,'B relle']],...
		'position',[310,407,365,443])


%     Subsystem  'Extras3'.

new_system([sys,'/','Extras3'])
set_param([sys,'/','Extras3'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras3'],...
		'Mask Display','Courbe\n drive B\nmesure',...
		'Mask Dialogue','eval(''plot(temps,derb_chapeau);grid;gcf'')')


%     Finished composite block 'Extras3'.

set_param([sys,'/','Extras3'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[360,25,575,116])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','Courbe de Breel',...
		'Mask Dialogue','eval(''plot(temps,champ_reel);grid;gcf'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[70,480,285,571])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Courbe du champ\n\n pulse linaris',...
		'Mask Dialogue','eval(''plot(temps,champ_pulse);grid;shg'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[850,25,1070,121])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Courbe de la\n\ndrive relle',...
		'Mask Dialogue','eval(''plot(temps,derBreel);grid;shg'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[610,25,825,116])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Comparaison\n\ndes drives',...
		'Mask Dialogue','eval(''plot(temps,derb_chapeau,temps,derBreel);grid;gcf'')')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[475,130,690,221])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,50,1012,686])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\n\n LANCE totdatP.m',...
		'Mask Dialogue','eval(''totdatP'');')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[860,490,1075,581])
add_line(sys,[280,345;405,345])
add_line(sys,[90,345;115,345])
add_line(sys,[370,425;410,425])
add_line(sys,[90,345;90,465;410,465])
add_line(sys,[330,345;330,265;405,265])
add_line(sys,[555,445;640,445])
add_line(sys,[550,360;595,360;595,395;640,395])
add_line(sys,[675,420;730,420])
add_line(sys,[550,325;730,325])
add_line(sys,[765,375;820,375])
add_line(sys,[370,425;370,540;420,540])
add_line(sys,[290,345;290,425;305,425])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
