function [ret,x0,str,ts,xts]=bbbestim(t,x,u,flag);
%BBBESTIM	is the M-file description of the SIMULINK system named BBBESTIM.
%	The block-diagram can be displayed by typing: BBBESTIM.
%
%	SYS=BBBESTIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BBBESTIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BBBESTIM with a FLAG of zero:
%	[SIZES]=BBBESTIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[11,172,1266,897])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     'instant_injection+6100')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '2')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','n')

add_block('built-in/Note',[sys,'/','derb_chapeau'])
set_param([sys,'/','derb_chapeau'],...
		'position',[645,570,650,575])

add_block('built-in/Note',[sys,'/','Drive B'])
set_param([sys,'/','Drive B'],...
		'position',[605,505,610,510])


%     Subsystem  'CHAMP MESURE'.

new_system([sys,'/','CHAMP MESURE'])
set_param([sys,'/','CHAMP MESURE'],'Location',[371,349,1080,713])
open_system([sys,'/','CHAMP MESURE'])

add_block('built-in/MATLAB Fcn',[sys,'/',['CHAMP MESURE/Partie',13,'entire n']])
set_param([sys,'/',['CHAMP MESURE/Partie',13,'entire n']],...
		'hide name',0,...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[130,233,190,267])

add_block('built-in/Sum',[sys,'/','CHAMP MESURE/Sum'])
set_param([sys,'/','CHAMP MESURE/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[235,159,255,281])

add_block('built-in/To Workspace',[sys,'/','CHAMP MESURE/To Workspace2'])
set_param([sys,'/','CHAMP MESURE/To Workspace2'],...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[180,123,245,137])

add_block('built-in/Clock',[sys,'/','CHAMP MESURE/Clock2'])
set_param([sys,'/','CHAMP MESURE/Clock2'],...
		'hide name',0,...
		'position',[40,230,80,270])

add_block('built-in/Inport',[sys,'/','CHAMP MESURE/in_1'])
set_param([sys,'/','CHAMP MESURE/in_1'],...
		'position',[40,80,60,100])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Entre de B(t) //xyz '])
set_param([sys,'/','CHAMP MESURE/Entre de B(t) //xyz '],...
		'position',[90,50,95,55])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[65,190,70,195])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Calcul t-nT'])
set_param([sys,'/','CHAMP MESURE/Calcul t-nT'],...
		'hide name',0,...
		'position',[240,300,245,305])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/t-nT'])
set_param([sys,'/','CHAMP MESURE/t-nT'],...
		'position',[930,355,935,360])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Sortie champ B chapeau'])
set_param([sys,'/','CHAMP MESURE/Sortie champ B chapeau'],...
		'position',[595,50,600,55])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/t - nT'])
set_param([sys,'/','CHAMP MESURE/t - nT'],...
		'position',[310,220,315,225])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[190,70,195,75])

add_block('built-in/Mux',[sys,'/','CHAMP MESURE/Mux1'])
set_param([sys,'/','CHAMP MESURE/Mux1'],...
		'inputs','[3 1]',...
		'position',[420,81,450,114])

add_block('built-in/MATLAB Fcn',[sys,'/',['CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3',...
		'position',[480,83,540,117])

add_block('built-in/Note',[sys,'/',['CHAMP MESURE/Partie',13,'entire de',13,'t//T']])
set_param([sys,'/',['CHAMP MESURE/Partie',13,'entire de',13,'t//T']],...
		'position',[150,275,155,280])

add_block('built-in/Outport',[sys,'/','CHAMP MESURE/out_2'])
set_param([sys,'/','CHAMP MESURE/out_2'],...
		'Port','2',...
		'position',[590,290,610,310])

add_block('built-in/Outport',[sys,'/','CHAMP MESURE/out_1'])
set_param([sys,'/','CHAMP MESURE/out_1'],...
		'position',[585,90,605,110])

add_block('built-in/To Workspace',[sys,'/','CHAMP MESURE/To Workspace3'])
set_param([sys,'/','CHAMP MESURE/To Workspace3'],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[585,142,635,158])

add_block('built-in/Relational Operator',[sys,'/',['CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[350,128,375,252])

add_block('built-in/Constant',[sys,'/','CHAMP MESURE/Constant1'])
set_param([sys,'/','CHAMP MESURE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[280,149,315,171])

add_block('built-in/Note',[sys,'/','CHAMP MESURE/Sortie de to = t - nT'])
set_param([sys,'/','CHAMP MESURE/Sortie de to = t - nT'],...
		'position',[560,255,565,260])
add_line([sys,'/','CHAMP MESURE'],[260,220;345,220])
add_line([sys,'/','CHAMP MESURE'],[85,250;125,250])
add_line([sys,'/','CHAMP MESURE'],[115,250;115,190;230,190])
add_line([sys,'/','CHAMP MESURE'],[165,190;175,130])
add_line([sys,'/','CHAMP MESURE'],[195,250;230,250])
add_line([sys,'/','CHAMP MESURE'],[65,90;415,90])
add_line([sys,'/','CHAMP MESURE'],[260,220;260,300;585,300])
add_line([sys,'/','CHAMP MESURE'],[455,100;475,100])
add_line([sys,'/','CHAMP MESURE'],[545,100;580,100])
add_line([sys,'/','CHAMP MESURE'],[380,190;405,190;415,105])
add_line([sys,'/','CHAMP MESURE'],[565,100;565,150;580,150])
add_line([sys,'/','CHAMP MESURE'],[320,160;345,160])
set_param([sys,'/','CHAMP MESURE'],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block 'CHAMP MESURE'.

set_param([sys,'/','CHAMP MESURE'],...
		'position',[410,398,545,467])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[785,369,810,556])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'position',[645,462,670,558])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[120,409,275,461])

add_block('built-in/Note',[sys,'/',['Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[190,460,195,465])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[65,425,85,445])

add_block('built-in/Note',[sys,'/','Temps'])
set_param([sys,'/','Temps'],...
		'position',[65,390,70,395])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'mat-name','champ_reel',...
		'buffer','20000',...
		'position',[410,338,530,372])

add_block('built-in/Note',[sys,'/','B(n)'])
set_param([sys,'/','B(n)'],...
		'position',[640,390,645,395])

add_block('built-in/Note',[sys,'/','t - nT'])
set_param([sys,'/','t - nT'],...
		'position',[615,455,620,460])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[890,448,1010,482])

add_block('built-in/Note',[sys,'/','Calcul t-nT'])
set_param([sys,'/','Calcul t-nT'],...
		'hide name',0,...
		'position',[520,620,525,625])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','derBreel',...
		'buffer','20000',...
		'position',[425,613,545,647])


%     Subsystem  'DERIVEE MESUREE'.

new_system([sys,'/','DERIVEE MESUREE'])
set_param([sys,'/','DERIVEE MESUREE'],'Location',[-68,329,1150,1021])
open_system([sys,'/','DERIVEE MESUREE'])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'])
set_param([sys,'/','DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/To Workspace',[sys,'/','DERIVEE MESUREE/To Workspace6'])
set_param([sys,'/','DERIVEE MESUREE/To Workspace6'],...
		'hide name',0,...
		'mat-name','derb_lin',...
		'buffer','20000',...
		'position',[845,381,920,419])

add_block('built-in/Sum',[sys,'/','DERIVEE MESUREE/Sum1'])
set_param([sys,'/','DERIVEE MESUREE/Sum1'],...
		'hide name',0,...
		'position',[780,304,805,491])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/Sortie de la drive',13,' linarise']])
set_param([sys,'/',['DERIVEE MESUREE/Sortie de la drive',13,' linarise']],...
		'position',[915,420,920,425])

add_block('built-in/Product',[sys,'/','DERIVEE MESUREE/Product'])
set_param([sys,'/','DERIVEE MESUREE/Product'],...
		'position',[720,397,745,493])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Entre de dB//dt //xyz '])
set_param([sys,'/','DERIVEE MESUREE/Entre de dB//dt //xyz '],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Sortie B_prime'])
set_param([sys,'/','DERIVEE MESUREE/Sortie B_prime'],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/','DERIVEE MESUREE/Mux1'])
set_param([sys,'/','DERIVEE MESUREE/Mux1'],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/t-nT'])
set_param([sys,'/','DERIVEE MESUREE/t-nT'],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/','DERIVEE MESUREE/Constant1'])
set_param([sys,'/','DERIVEE MESUREE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/Sum',[sys,'/','DERIVEE MESUREE/Sum'])
set_param([sys,'/','DERIVEE MESUREE/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[290,199,310,321])

add_block('built-in/Inport',[sys,'/','DERIVEE MESUREE/in_2'])
set_param([sys,'/','DERIVEE MESUREE/in_2'],...
		'Port','2',...
		'position',[105,280,125,300])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Temps'])
set_param([sys,'/','DERIVEE MESUREE/Temps'],...
		'position',[225,205,230,210])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/nT'])
set_param([sys,'/','DERIVEE MESUREE/nT'],...
		'position',[265,265,270,270])

add_block('built-in/MATLAB Fcn',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire n']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire n']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[185,273,245,307])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire de',13,'t//T']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire de',13,'t//T']],...
		'position',[215,345,220,350])

add_block('built-in/To Workspace',[sys,'/','DERIVEE MESUREE/To Workspace5'])
set_param([sys,'/','DERIVEE MESUREE/To Workspace5'],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/t-nT<=Ta'])
set_param([sys,'/','DERIVEE MESUREE/t-nT<=Ta'],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/','DERIVEE MESUREE/in_1'])
set_param([sys,'/','DERIVEE MESUREE/in_1'],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3',...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/','DERIVEE MESUREE/To File'])
set_param([sys,'/','DERIVEE MESUREE/To File'],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/','DERIVEE MESUREE/out_1'])
set_param([sys,'/','DERIVEE MESUREE/out_1'],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[110,320,115,325])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/Sortie de t-nT'])
set_param([sys,'/','DERIVEE MESUREE/Sortie de t-nT'],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/t -  nT'])
set_param([sys,'/','DERIVEE MESUREE/t -  nT'],...
		'position',[410,440,415,445])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/B(n)'])
set_param([sys,'/','DERIVEE MESUREE/B(n)'],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/','DERIVEE MESUREE/derb_chapeau'])
set_param([sys,'/','DERIVEE MESUREE/derb_chapeau'],...
		'position',[785,211,790,216])

add_block('built-in/Note',[sys,'/',['DERIVEE MESUREE/drive seconde',13,'approxime']])
set_param([sys,'/',['DERIVEE MESUREE/drive seconde',13,'approxime']],...
		'position',[415,388,420,393])

add_block('built-in/To Workspace',[sys,'/','DERIVEE MESUREE/To Workspace7'])
set_param([sys,'/','DERIVEE MESUREE/To Workspace7'],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])

add_block('built-in/MATLAB Fcn',[sys,'/',['DERIVEE MESUREE/Partie',13,'entire n3']])
set_param([sys,'/',['DERIVEE MESUREE/Partie',13,'entire n3']],...
		'hide name',0,...
		'MATLAB Fcn','stor_B2(u)',...
		'Output Width','3',...
		'position',[580,403,640,437])
add_line([sys,'/','DERIVEE MESUREE'],[130,290;180,290])
add_line([sys,'/','DERIVEE MESUREE'],[145,290;145,230;285,230])
add_line([sys,'/','DERIVEE MESUREE'],[250,290;285,290])
add_line([sys,'/','DERIVEE MESUREE'],[315,260;370,260])
add_line([sys,'/','DERIVEE MESUREE'],[130,145;430,145;430,215;450,215])
add_line([sys,'/','DERIVEE MESUREE'],[365,200;370,200])
add_line([sys,'/','DERIVEE MESUREE'],[405,230;450,230])
add_line([sys,'/','DERIVEE MESUREE'],[490,225;510,225])
add_line([sys,'/','DERIVEE MESUREE'],[580,225;710,225])
add_line([sys,'/','DERIVEE MESUREE'],[595,225;595,285;625,285])
add_line([sys,'/','DERIVEE MESUREE'],[595,225;595,150;630,150])
add_line([sys,'/','DERIVEE MESUREE'],[490,225;490,420;575,420])
add_line([sys,'/','DERIVEE MESUREE'],[750,445;775,445])
add_line([sys,'/','DERIVEE MESUREE'],[645,420;715,420])
add_line([sys,'/','DERIVEE MESUREE'],[340,260;340,470;715,470])
add_line([sys,'/','DERIVEE MESUREE'],[600,285;600,350;775,350])
add_line([sys,'/','DERIVEE MESUREE'],[810,400;840,400])
add_line([sys,'/','DERIVEE MESUREE'],[675,420;675,585;700,585])
set_param([sys,'/','DERIVEE MESUREE'],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block 'DERIVEE MESUREE'.

set_param([sys,'/','DERIVEE MESUREE'],...
		'position',[420,495,555,575])

add_block('built-in/Derivative',[sys,'/',['Drive de',13,'B relle']])
set_param([sys,'/',['Drive de',13,'B relle']],...
		'position',[310,497,365,533])

add_block('built-in/Clock',[sys,'/','Clock1'])
set_param([sys,'/','Clock1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[1045,286,1130,374])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Diffrence\nchamp rel, champ pulse\nsimple',...
		'Mask Dialogue','eval(''plot(temps(110:length(temps)),champ_reel(110:length(temps))-champ1(110:length(temps)));grid;gcf'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[35,70,260,166])

add_block('built-in/Note',[sys,'/',['SIMULATION DE MISE AU POINT DU CHAMP MAGNETIQUE  PULSE',13,'ET DE LA DERIVEE PULSEE DU CHAMP MAGNETIQUE']])
set_param([sys,'/',['SIMULATION DE MISE AU POINT DU CHAMP MAGNETIQUE  PULSE',13,'ET DE LA DERIVEE PULSEE DU CHAMP MAGNETIQUE']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22)
set_param([sys,'/',['SIMULATION DE MISE AU POINT DU CHAMP MAGNETIQUE  PULSE',13,'ET DE LA DERIVEE PULSEE DU CHAMP MAGNETIQUE']],...
		'position',[570,5,575,10])


%     Subsystem  'Extras4'.

new_system([sys,'/','Extras4'])
set_param([sys,'/','Extras4'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras4'],...
		'Mask Display','Drive de B pulse\nsimple',...
		'Mask Dialogue','eval(''plot(temps,derb_chapeau);grid;shg'')')


%     Finished composite block 'Extras4'.

set_param([sys,'/','Extras4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[40,170,255,261])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','Courbe de Breel',...
		'Mask Dialogue','eval(''plot(temps,champ_reel);grid;gcf'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[35,265,250,356])


%     Subsystem  'Extras3'.

new_system([sys,'/','Extras3'])
set_param([sys,'/','Extras3'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras3'],...
		'Mask Display','Courbe\n drive B\nmesure',...
		'Mask Dialogue','eval(''plot(temps,derb_chapeau);grid;gcf'')')


%     Finished composite block 'Extras3'.

set_param([sys,'/','Extras3'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[265,75,480,166])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Comparaison\n\ndes drives',...
		'Mask Dialogue','eval(''plot(temps,derb_chapeau,temps,derBreel);grid;gcf'')')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[265,180,480,271])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Courbe de la\n\ndrive relle',...
		'Mask Dialogue','eval(''plot(temps,derBreel);grid;shg'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[490,80,705,171])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Courbe\n drive B\nlinarise',...
		'Mask Dialogue','eval(''plot(temps(100:length(temps)),derb_lin(100:length(temps)));grid;gcf'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[490,180,705,271])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Courbe du champ\n\n pulse linaris',...
		'Mask Dialogue','eval(''plot(temps,champ_pulse);grid;shg'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[715,80,935,176])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Les courbes\nchamp pulse linaris\nchamp rel',...
		'Mask Dialogue','eval(''plot(temps,champ_pulse,temps,champ_reel);grid;shg'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[720,185,945,271])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Diffrence\nchamp rel, champ pulse\nsimple',...
		'Mask Dialogue','eval(''plot(temps(110:length(temps)),champ_reel(110:length(temps),1:3)-champ_pulse(110:length(temps),1:3));grid;gcf'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[940,80,1165,176])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,50,1012,686])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\n\n LANCE totdatP.m',...
		'Mask Dialogue','eval(''totdatP'');')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[955,180,1170,271])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Drive de B pulse\nlinarise',...
		'Mask Dialogue','eval(''plot(temps,derb_pulse);grid;shg'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[950,605,1165,696])
add_line(sys,[280,435;405,435])
add_line(sys,[90,435;115,435])
add_line(sys,[370,515;415,515])
add_line(sys,[90,435;90,555;415,555])
add_line(sys,[330,435;330,355;405,355])
add_line(sys,[550,450;595,450;595,485;640,485])
add_line(sys,[675,510;780,510])
add_line(sys,[550,415;780,415])
add_line(sys,[815,465;885,465])
add_line(sys,[370,515;370,630;420,630])
add_line(sys,[290,435;290,515;305,515])
add_line(sys,[560,535;640,535])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
