function [ret,x0,str,ts,xts]=casaa0(t,x,u,flag);
%CASAA0	is the M-file description of the SIMULINK system named CASAA0.
%	The block-diagram can be displayed by typing: CASAA0.
%
%	SYS=CASAA0(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CASAA0 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CASAA0 with a FLAG of zero:
%	[SIZES]=CASAA0([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[17,57,1280,954])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '4000')
set_param(sys,'Min step size', '0.2')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','n')


%     Subsystem  'Graphiques'.

new_system([sys,'/','Graphiques'])
set_param([sys,'/','Graphiques'],'Location',[25,6553675,1165,6554120])


%     Subsystem  'Graphiques/Extras27'.

new_system([sys,'/','Graphiques/Extras27'])
set_param([sys,'/','Graphiques/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras27'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r,temps,switch_long/10);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras27'.

set_param([sys,'/','Graphiques/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[15,240,220,301])


%     Subsystem  'Graphiques/Extras22'.

new_system([sys,'/','Graphiques/Extras22'])
set_param([sys,'/','Graphiques/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras22'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras22'.

set_param([sys,'/','Graphiques/Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,310,225,371])


%     Subsystem  'Graphiques/Extras29'.

new_system([sys,'/','Graphiques/Extras29'])
set_param([sys,'/','Graphiques/Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras29'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras29'.

set_param([sys,'/','Graphiques/Extras29'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,325,480,381])


%     Subsystem  'Graphiques/Extras21'.

new_system([sys,'/','Graphiques/Extras21'])
set_param([sys,'/','Graphiques/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras21'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras21'.

set_param([sys,'/','Graphiques/Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,235,710,301])


%     Subsystem  'Graphiques/Extras20'.

new_system([sys,'/','Graphiques/Extras20'])
set_param([sys,'/','Graphiques/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras20'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras20'.

set_param([sys,'/','Graphiques/Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[510,315,710,381])

add_block('built-in/Note',[sys,'/','Graphiques/SORTIES GRAPHIQUES'])
set_param([sys,'/','Graphiques/SORTIES GRAPHIQUES'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[525,50,530,55])


%     Subsystem  'Graphiques/Extras30'.

new_system([sys,'/','Graphiques/Extras30'])
set_param([sys,'/','Graphiques/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras30'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras30'.

set_param([sys,'/','Graphiques/Extras30'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,160,710,216])


%     Subsystem  'Graphiques/Extras34'.

new_system([sys,'/','Graphiques/Extras34'])
set_param([sys,'/','Graphiques/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras34'],...
		'Mask Display','Voir courbe\nchangement\nde rgulation',...
		'Mask Dialogue','eval(''plot(temps,switch_long);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras34'.

set_param([sys,'/','Graphiques/Extras34'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,315,1100,381])


%     Subsystem  'Graphiques/Extras32'.

new_system([sys,'/','Graphiques/Extras32'])
set_param([sys,'/','Graphiques/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras32'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras32'.

set_param([sys,'/','Graphiques/Extras32'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,235,1100,301])


%     Subsystem  'Graphiques/Extras23'.

new_system([sys,'/','Graphiques/Extras23'])
set_param([sys,'/','Graphiques/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras23'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet,temps,switch_long*100);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras23'.

set_param([sys,'/','Graphiques/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,155,220,221])


%     Subsystem  'Graphiques/Extras24'.

new_system([sys,'/','Graphiques/Extras24'])
set_param([sys,'/','Graphiques/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras24'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras24'.

set_param([sys,'/','Graphiques/Extras24'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,165,910,231])


%     Subsystem  'Graphiques/Extras25'.

new_system([sys,'/','Graphiques/Extras25'])
set_param([sys,'/','Graphiques/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras25'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras25'.

set_param([sys,'/','Graphiques/Extras25'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,240,910,306])


%     Subsystem  'Graphiques/Extras26'.

new_system([sys,'/','Graphiques/Extras26'])
set_param([sys,'/','Graphiques/Extras26'],'Location',[4,50,1012,686])
set_param([sys,'/','Graphiques/Extras26'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Graphiques/Extras26'.

set_param([sys,'/','Graphiques/Extras26'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,225,475,311])


%     Subsystem  'Graphiques/Extras28'.

new_system([sys,'/','Graphiques/Extras28'])
set_param([sys,'/','Graphiques/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras28'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx_deriv, my_deriv, mz_deriv')
set_param([sys,'/','Graphiques/Extras28'],...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv,temps,switch_long*0.2);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras28'.

set_param([sys,'/','Graphiques/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,155,490,216])


%     Subsystem  'Graphiques/Extras31'.

new_system([sys,'/','Graphiques/Extras31'])
set_param([sys,'/','Graphiques/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras31'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue,temps,switch_long*4e-6);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras31'.

set_param([sys,'/','Graphiques/Extras31'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,160,1100,226])


%     Subsystem  'Graphiques/Extras33'.

new_system([sys,'/','Graphiques/Extras33'])
set_param([sys,'/','Graphiques/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras33'],...
		'Mask Display','Voir courbe\ncomposantes\n\n By et BY du champ',...
		'Mask Dialogue','eval(''plot(temps,BY,temps,By);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras33'.

set_param([sys,'/','Graphiques/Extras33'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,310,905,386])
set_param([sys,'/','Graphiques'],...
		'Mask Display','SORTIES|\n\nGRAPHIQUES')


%     Finished composite block 'Graphiques'.

set_param([sys,'/','Graphiques'],...
		'position',[1275,730,1530,786])

add_block('built-in/Note',[sys,'/',['STABILISATION TOTALE DU LANCEMENT AUX PREMIERES PHOTOS',13,'PHASE DE DETUMBLING JUSQU''A L''ACQUISITION FINE']])
set_param([sys,'/',['STABILISATION TOTALE DU LANCEMENT AUX PREMIERES PHOTOS',13,'PHASE DE DETUMBLING JUSQU''A L''ACQUISITION FINE']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[703,5,708,10])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE  ET DE DEUX TYPES DE REGULATION',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE  ET DE DEUX TYPES DE REGULATION',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[685,75,690,80])

add_block('built-in/Note',[sys,'/','CHAMP MAGNETIQUE AVEC MESURES ( En tenant compte des contraintes de la mesure ), PAS DE ROUE'])
set_param([sys,'/','CHAMP MAGNETIQUE AVEC MESURES ( En tenant compte des contraintes de la mesure ), PAS DE ROUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[655,115,660,120])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','RETROUVER LES PRINCIPALES CARACTERISTIQUES DANS L''ESPACE MATLAB',...
		'Mask Dialogue','eval(''display0'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[130,850,815,886])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[17,63,1245,789])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT RAPIDEMENT UTILISER LA SIMULATION ?'])
set_param([sys,'/','Subsystem1/COMMENT RAPIDEMENT UTILISER LA SIMULATION ?'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou fvrier 2014'])
set_param([sys,'/','Subsystem1/Robert Guiziou fvrier 2014'],...
		'ForeGround',2,...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes puldatNP ( sans pulse ) ou puldatP ( avec pulse ) '])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes puldatNP ( sans pulse ) ou puldatP ( avec pulse ) '],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[680,210,685,215])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans la boite SORTIES GRAPHIQUES qui prsente les sorties au choix'])
set_param([sys,'/','Subsystem1/a) En cliquant dans la boite SORTIES GRAPHIQUES qui prsente les sorties au choix'],...
		'Font Size',14,...
		'position',[550,400,555,405])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[335,365,340,370])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB : Les couleurs lors de 3 sorties sont en gnral ( si 3 sorties )',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB : Les couleurs lors de 3 sorties sont en gnral ( si 3 sorties )',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[550,515,555,520])

add_block('built-in/Note',[sys,'/','Subsystem1/5 - SYNTHESE DES RESULTATS :      Cliquer sur '])
set_param([sys,'/','Subsystem1/5 - SYNTHESE DES RESULTATS :      Cliquer sur '],...
		'ForeGround',5,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[375,610,380,615])

add_block('built-in/Note',[sys,'/','Subsystem1/RETROUVER LES CARACTERISTIQUES MISSION'])
set_param([sys,'/','Subsystem1/RETROUVER LES CARACTERISTIQUES MISSION'],...
		'ForeGround',5,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[920,610,925,615])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est puldatP.m ( simulation pulse ) ou puldatN( non pulse)']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est puldatP.m ( simulation pulse ) ou puldatN( non pulse)']],...
		'Font Size',14,...
		'position',[510,125,515,130])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 4000  10000 ( plutt vers 5000) secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 4000  10000 ( plutt vers 5000) secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[635,240,640,245])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[300,265,305,270])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[485,90,490,95])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[400,160,405,165])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que les stop ( paramtrables ) arrtent les calculs quand les vitesses sont suffisamment rduites ou les angles faibles'])
set_param([sys,'/','Subsystem1/3 - Attendre que les stop ( paramtrables ) arrtent les calculs quand les vitesses sont suffisamment rduites ou les angles faibles'],...
		'Font Size',14,...
		'position',[635,295,640,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB : Les stop peuvent tre inactivs en portant leur gain  0, dans leur masque'])
set_param([sys,'/','Subsystem1/NB : Les stop peuvent tre inactivs en portant leur gain  0, dans leur masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,325,520,330])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[865,845,1215,886])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','INITIALISATION\n(puldatP.m)\n par double clic souris\nCAS PULSE',...
		'Mask Dialogue','eval(''puldatP'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1055,705,1270,796])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Value','0',...
		'position',[345,345,365,365])

add_block('built-in/Constant',[sys,'/','Constant2'])
set_param([sys,'/','Constant2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Value','0',...
		'position',[345,365,365,385])

add_block('built-in/Constant',[sys,'/','Constant3'])
set_param([sys,'/','Constant3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Value','0',...
		'position',[345,385,365,405])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'inputs','3',...
		'position',[390,341,420,409])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Value','0',...
		'position',[120,479,155,501])

add_block('built-in/Note',[sys,'/','Hcheur'])
set_param([sys,'/','Hcheur'],...
		'position',[630,290,635,295])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[98,234,990,830])

add_block('built-in/Note',[sys,'/',['Subsystem2/SEQUENCEUR FAISANT BASCULER DU MODE "BPOINT"',13,' AU MODE ACQUISITION GROSSIERE PUIS FINE',13,'SUR DETECTION D''UN SEUIL DE VITESSE']])
set_param([sys,'/',['Subsystem2/SEQUENCEUR FAISANT BASCULER DU MODE "BPOINT"',13,' AU MODE ACQUISITION GROSSIERE PUIS FINE',13,'SUR DETECTION D''UN SEUIL DE VITESSE']],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['Subsystem2/SEQUENCEUR FAISANT BASCULER DU MODE "BPOINT"',13,' AU MODE ACQUISITION GROSSIERE PUIS FINE',13,'SUR DETECTION D''UN SEUIL DE VITESSE']],...
		'Font Size',16,...
		'position',[520,25,525,30])

add_block('built-in/Note',[sys,'/','Subsystem2/NB : La mise  1 du stop permet de ne raliser que la rduction des vitesses en "Bpoint'])
set_param([sys,'/','Subsystem2/NB : La mise  1 du stop permet de ne raliser que la rduction des vitesses en "Bpoint'],...
		'ForeGround',1,...
		'position',[615,0,620,5])

add_block('built-in/Note',[sys,'/',['Subsystem2/La mise  1 su stop permet de n''effectuer que la rgulation en "BPOINT"',13,'']])
set_param([sys,'/',['Subsystem2/La mise  1 su stop permet de n''effectuer que la rgulation en "BPOINT"',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'position',[500,100,505,105])

add_block('built-in/Note',[sys,'/','Subsystem2/Sortie du switch1 ( valeur 1 ou 0)'])
set_param([sys,'/','Subsystem2/Sortie du switch1 ( valeur 1 ou 0)'],...
		'ForeGround',1,...
		'position',[700,260,705,265])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[510,504,515,509])

add_block('built-in/Note',[sys,'/',['Subsystem2/1 si w > vitesse_angul_mini',13,'0 si w < =vitesse_angul_mini',13,'',13,'K_tumbling vaut en mode Bpoint',13,'et 0 en mode acquisition']])
set_param([sys,'/',['Subsystem2/1 si w > vitesse_angul_mini',13,'0 si w < =vitesse_angul_mini',13,'',13,'K_tumbling vaut en mode Bpoint',13,'et 0 en mode acquisition']],...
		'ForeGround',7,...
		'Font Name','Arial')
set_param([sys,'/',['Subsystem2/1 si w > vitesse_angul_mini',13,'0 si w < =vitesse_angul_mini',13,'',13,'K_tumbling vaut en mode Bpoint',13,'et 0 en mode acquisition']],...
		'position',[220,195,225,200])

add_block('built-in/Constant',[sys,'/','Subsystem2/Constant'])
set_param([sys,'/','Subsystem2/Constant'],...
		'position',[470,450,490,470])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[735,421,790,479])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation1'])
set_param([sys,'/','Subsystem2/Stop Simulation1'],...
		'position',[385,396,440,454])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt1']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'Mask Display','Stop rduction\nvitesses')
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt1']],...
		'position',[245,404,340,446])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum'])
set_param([sys,'/','Subsystem2/Sum'],...
		'inputs','-+',...
		'position',[525,424,555,471])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'position',[615,433,695,467])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[160,305,180,325])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace13'])
set_param([sys,'/','Subsystem2/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','switch1',...
		'buffer','1',...
		'position',[505,257,600,293])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','stoptumb(u)',...
		'Output Width','1',...
		'Mask Display','Stop\ndetumbling')
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'position',[250,294,320,336])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace12'])
set_param([sys,'/','Subsystem2/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','K_tumbling',...
		'buffer','1',...
		'position',[360,257,455,293])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/MATLAB Fcn'])
set_param([sys,'/','Subsystem2/MATLAB Fcn'],...
		'MATLAB Fcn','souvenir(u)',...
		'Output Width','1',...
		'position',[380,298,440,332])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/out_1'],...
		'position',[620,305,640,325])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace14'])
set_param([sys,'/','Subsystem2/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','switch_long',...
		'buffer','points_trace',...
		'position',[510,352,605,388])


%     Subsystem  'Subsystem2/Subsystem'.

new_system([sys,'/','Subsystem2/Subsystem'])
set_param([sys,'/','Subsystem2/Subsystem'],'Location',[15,70,530,365])

add_block('built-in/Note',[sys,'/',['Subsystem2/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']])
set_param([sys,'/',['Subsystem2/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[255,35,260,40])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem2/Subsystem/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem2/Subsystem/Relational',13,'Operator']],...
		'hide name',0,...
		'Operator','<=',...
		'position',[265,96,290,169])

add_block('built-in/Product',[sys,'/','Subsystem2/Subsystem/Product'])
set_param([sys,'/','Subsystem2/Subsystem/Product'],...
		'hide name',0,...
		'position',[335,110,360,205])

add_block('built-in/To File',[sys,'/','Subsystem2/Subsystem/To File4'])
set_param([sys,'/','Subsystem2/Subsystem/To File4'],...
		'hide name',0,...
		'File name','B_point.mat',...
		'Matrix name','temps_Bpoint',...
		'position',[395,137,485,183])

add_block('built-in/Clock',[sys,'/','Subsystem2/Subsystem/Clock1'])
set_param([sys,'/','Subsystem2/Subsystem/Clock1'],...
		'hide name',0,...
		'position',[80,203,140,257])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem2/Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[160,180,230,200])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem/in_1'])
set_param([sys,'/','Subsystem2/Subsystem/in_1'],...
		'position',[155,140,175,160])

add_block('built-in/Constant',[sys,'/','Subsystem2/Subsystem/Constant'])
set_param([sys,'/','Subsystem2/Subsystem/Constant'],...
		'position',[150,104,220,126])
add_line([sys,'/','Subsystem2/Subsystem'],[365,160;390,160])
add_line([sys,'/','Subsystem2/Subsystem'],[145,230;245,230;245,180;330,180])
add_line([sys,'/','Subsystem2/Subsystem'],[295,135;330,135])
add_line([sys,'/','Subsystem2/Subsystem'],[145,230;155,190])
add_line([sys,'/','Subsystem2/Subsystem'],[225,115;260,115])
add_line([sys,'/','Subsystem2/Subsystem'],[180,150;260,150])
set_param([sys,'/','Subsystem2/Subsystem'],...
		'Mask Display','TEMPS B_POINT')


%     Finished composite block 'Subsystem2/Subsystem'.

set_param([sys,'/','Subsystem2/Subsystem'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[500,200,615,240])
add_line([sys,'/','Subsystem2'],[445,315;615,315])
add_line([sys,'/','Subsystem2'],[445,315;470,315;470,275;500,275])
add_line([sys,'/','Subsystem2'],[325,315;335,315;335,275;355,275])
add_line([sys,'/','Subsystem2'],[335,315;375,315])
add_line([sys,'/','Subsystem2'],[185,315;245,315])
add_line([sys,'/','Subsystem2'],[470,315;470,370;505,370])
add_line([sys,'/','Subsystem2'],[185,315;185,425;240,425])
add_line([sys,'/','Subsystem2'],[700,450;730,450])
add_line([sys,'/','Subsystem2'],[345,425;380,425])
add_line([sys,'/','Subsystem2'],[560,450;610,450])
add_line([sys,'/','Subsystem2'],[495,460;520,460])
add_line([sys,'/','Subsystem2'],[470,365;470,435;520,435])
add_line([sys,'/','Subsystem2'],[470,275;470,220;495,220])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','SWITCH1\nBpoint\nvers\nAcquisition')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'position',[30,296,135,394])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\n(puldatNP.m)\n par double clic souris\nCAS NON PULSE',...
		'Mask Dialogue','eval(''puldatNP'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1050,495,1265,586])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[920,623,955,657])


%     Subsystem  'Graphes'.

new_system([sys,'/','Graphes'])
set_param([sys,'/','Graphes'],'Location',[31,271,1243,1002])
open_system([sys,'/','Graphes'])


%     Subsystem  'Graphes/Extras22'.

new_system([sys,'/','Graphes/Extras22'])
set_param([sys,'/','Graphes/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras22'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras22'.

set_param([sys,'/','Graphes/Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,310,225,371])


%     Subsystem  'Graphes/Extras29'.

new_system([sys,'/','Graphes/Extras29'])
set_param([sys,'/','Graphes/Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras29'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras29'.

set_param([sys,'/','Graphes/Extras29'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,325,480,381])


%     Subsystem  'Graphes/Extras21'.

new_system([sys,'/','Graphes/Extras21'])
set_param([sys,'/','Graphes/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras21'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras21'.

set_param([sys,'/','Graphes/Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,235,710,301])


%     Subsystem  'Graphes/Extras20'.

new_system([sys,'/','Graphes/Extras20'])
set_param([sys,'/','Graphes/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras20'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras20'.

set_param([sys,'/','Graphes/Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[510,315,710,381])


%     Subsystem  'Graphes/Extras30'.

new_system([sys,'/','Graphes/Extras30'])
set_param([sys,'/','Graphes/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras30'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras30'.

set_param([sys,'/','Graphes/Extras30'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,160,710,216])


%     Subsystem  'Graphes/Extras34'.

new_system([sys,'/','Graphes/Extras34'])
set_param([sys,'/','Graphes/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras34'],...
		'Mask Display','Voir courbe\nchangement\nde rgulation',...
		'Mask Dialogue','eval(''plot(temps,switch_long);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras34'.

set_param([sys,'/','Graphes/Extras34'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,315,1100,381])


%     Subsystem  'Graphes/Extras32'.

new_system([sys,'/','Graphes/Extras32'])
set_param([sys,'/','Graphes/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras32'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras32'.

set_param([sys,'/','Graphes/Extras32'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,235,1100,301])


%     Subsystem  'Graphes/Extras23'.

new_system([sys,'/','Graphes/Extras23'])
set_param([sys,'/','Graphes/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras23'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet,temps,switch_long*100);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras23'.

set_param([sys,'/','Graphes/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,155,220,221])


%     Subsystem  'Graphes/Extras24'.

new_system([sys,'/','Graphes/Extras24'])
set_param([sys,'/','Graphes/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras24'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras24'.

set_param([sys,'/','Graphes/Extras24'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,165,910,231])


%     Subsystem  'Graphes/Extras25'.

new_system([sys,'/','Graphes/Extras25'])
set_param([sys,'/','Graphes/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras25'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras25'.

set_param([sys,'/','Graphes/Extras25'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,240,910,306])


%     Subsystem  'Graphes/Extras26'.

new_system([sys,'/','Graphes/Extras26'])
set_param([sys,'/','Graphes/Extras26'],'Location',[4,50,1012,686])
set_param([sys,'/','Graphes/Extras26'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Graphes/Extras26'.

set_param([sys,'/','Graphes/Extras26'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,225,475,311])


%     Subsystem  'Graphes/Extras28'.

new_system([sys,'/','Graphes/Extras28'])
set_param([sys,'/','Graphes/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras28'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx_deriv, my_deriv, mz_deriv')
set_param([sys,'/','Graphes/Extras28'],...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv,temps,switch_long*0.2);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras28'.

set_param([sys,'/','Graphes/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,155,490,216])


%     Subsystem  'Graphes/Extras31'.

new_system([sys,'/','Graphes/Extras31'])
set_param([sys,'/','Graphes/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras31'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue,temps,switch_long*4e-6);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras31'.

set_param([sys,'/','Graphes/Extras31'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,160,1100,226])


%     Subsystem  'Graphes/Extras33'.

new_system([sys,'/','Graphes/Extras33'])
set_param([sys,'/','Graphes/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras33'],...
		'Mask Display','Voir courbe\ncomposantes\n\n By et BY du champ',...
		'Mask Dialogue','eval(''plot(temps,BY,temps,By);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras33'.

set_param([sys,'/','Graphes/Extras33'],...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,310,905,386])

add_block('built-in/Note',[sys,'/','Graphes/SORTIES GRAPHIQUES'])
set_param([sys,'/','Graphes/SORTIES GRAPHIQUES'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[535,25,540,30])

add_block('built-in/Note',[sys,'/','Graphes/Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Graphes/Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[545,85,550,90])


%     Subsystem  'Graphes/Extras27'.

new_system([sys,'/','Graphes/Extras27'])
set_param([sys,'/','Graphes/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras27'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r,temps,switch_long/10);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras27'.

set_param([sys,'/','Graphes/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[15,230,220,291])


%     Subsystem  'Graphes/Extras35'.

new_system([sys,'/','Graphes/Extras35'])
set_param([sys,'/','Graphes/Extras35'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras35'],...
		'Mask Display','Evolutions test_basculement\n\nswitch_long( x -1)',...
		'Mask Dialogue','eval(''plot(temps,test_basculement,temps,switch_long*(-1));grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras35'.

set_param([sys,'/','Graphes/Extras35'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[455,620,690,686])


%     Subsystem  'Graphes/Extras36'.

new_system([sys,'/','Graphes/Extras36'])
set_param([sys,'/','Graphes/Extras36'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras36'],...
		'Mask Display','Voir les courbes\ndu champ rel et \ndu champ puls\nsur le roulis',...
		'Mask Dialogue','eval(''plot(temps,Bx_reel,temps,Bx_pulse);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras36'.

set_param([sys,'/','Graphes/Extras36'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,460,225,536])

add_block('built-in/Note',[sys,'/','Graphes/COURBES DE CONTRLE'])
set_param([sys,'/','Graphes/COURBES DE CONTRLE'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[565,415,570,420])


%     Subsystem  'Graphes/Extras37'.

new_system([sys,'/','Graphes/Extras37'])
set_param([sys,'/','Graphes/Extras37'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras37'],...
		'Mask Display','Voir les courbes\ndu champ rel et \ndu champ en escalier\nsur le roulis',...
		'Mask Dialogue','eval(''plot(temps,Bx_reel,temps,Bx_cren);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras37'.

set_param([sys,'/','Graphes/Extras37'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,465,445,541])


%     Subsystem  'Graphes/Extras38'.

new_system([sys,'/','Graphes/Extras38'])
set_param([sys,'/','Graphes/Extras38'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras38'],...
		'Mask Display','Voir la courbe\ndu couple de commande\navant  hcheur',...
		'Mask Dialogue','eval(''plot(temps,com_avant);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras38'.

set_param([sys,'/','Graphes/Extras38'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[695,460,895,531])


%     Subsystem  'Graphes/Extras39'.

new_system([sys,'/','Graphes/Extras39'])
set_param([sys,'/','Graphes/Extras39'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras39'],...
		'Mask Display','Voir la courbe\ndu couple de commande\napres  hcheur',...
		'Mask Dialogue','eval(''plot(temps,com_apres,temps,creneau*1e-4);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras39'.

set_param([sys,'/','Graphes/Extras39'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[915,465,1115,536])
set_param([sys,'/','Graphes'],...
		'Mask Display','SORTIES\n\nGRAPHIQUES')


%     Finished composite block 'Graphes'.

set_param([sys,'/','Graphes'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[1050,610,1265,686])


%     Subsystem  'Stops'.

new_system([sys,'/','Stops'])
set_param([sys,'/','Stops'],'Location',[64,144,884,669])

add_block('built-in/Inport',[sys,'/','Stops/in_1'])
set_param([sys,'/','Stops/in_1'],...
		'position',[75,225,95,245])


%     Subsystem  'Stops/Stop detumbling2'.

new_system([sys,'/','Stops/Stop detumbling2'])
set_param([sys,'/','Stops/Stop detumbling2'],'Location',[769,541,1204,644])

add_block('built-in/Inport',[sys,'/','Stops/Stop detumbling2/in_1'])
set_param([sys,'/','Stops/Stop detumbling2/in_1'],...
		'position',[130,55,150,75])

add_block('built-in/Gain',[sys,'/','Stops/Stop detumbling2/Gain'])
set_param([sys,'/','Stops/Stop detumbling2/Gain'],...
		'BackGround',7,...
		'position',[230,48,310,82])

add_block('built-in/Stop Simulation',[sys,'/','Stops/Stop detumbling2/Stop Simulation'])
set_param([sys,'/','Stops/Stop detumbling2/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Note',[sys,'/','Stops/Stop detumbling2/Stop dsamorable'])
set_param([sys,'/','Stops/Stop detumbling2/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])
add_line([sys,'/','Stops/Stop detumbling2'],[155,65;225,65])
add_line([sys,'/','Stops/Stop detumbling2'],[315,65;345,65])
set_param([sys,'/','Stops/Stop detumbling2'],...
		'Mask Display','STOP DU MODE FIN\n\nDESAMORCABLE')


%     Finished composite block 'Stops/Stop detumbling2'.

set_param([sys,'/','Stops/Stop detumbling2'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[605,162,770,208])

add_block('built-in/Constant',[sys,'/','Stops/Constant2'])
set_param([sys,'/','Stops/Constant2'],...
		'Value','angle_mini_mod_fin',...
		'position',[270,134,440,156])

add_block('built-in/Demux',[sys,'/','Stops/Demux1'])
set_param([sys,'/','Stops/Demux1'],...
		'outputs','[3 3]',...
		'position',[240,207,280,263])

add_block('built-in/MATLAB Fcn',[sys,'/','Stops/fpqrQ_V_P1'])
set_param([sys,'/','Stops/fpqrQ_V_P1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'Mask Display','pqrQ_V_P',...
		'position',[125,214,195,256])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops/Valeur absolue',13,'des angles1']])
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil angulaire',...
		'position',[335,196,430,244])


%     Subsystem  'Stops/Stop detumbling3'.

new_system([sys,'/','Stops/Stop detumbling3'])
set_param([sys,'/','Stops/Stop detumbling3'],'Location',[724,654,1159,757])

add_block('built-in/Inport',[sys,'/','Stops/Stop detumbling3/in_1'])
set_param([sys,'/','Stops/Stop detumbling3/in_1'],...
		'position',[130,55,150,75])

add_block('built-in/Gain',[sys,'/','Stops/Stop detumbling3/Gain'])
set_param([sys,'/','Stops/Stop detumbling3/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[230,48,310,82])

add_block('built-in/Stop Simulation',[sys,'/','Stops/Stop detumbling3/Stop Simulation'])
set_param([sys,'/','Stops/Stop detumbling3/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Note',[sys,'/','Stops/Stop detumbling3/Stop dsamorable'])
set_param([sys,'/','Stops/Stop detumbling3/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])
add_line([sys,'/','Stops/Stop detumbling3'],[155,65;225,65])
add_line([sys,'/','Stops/Stop detumbling3'],[315,65;345,65])
set_param([sys,'/','Stops/Stop detumbling3'],...
		'Mask Display','STOP DU MODE FIN\n\nDESAMORCABLE')


%     Finished composite block 'Stops/Stop detumbling3'.

set_param([sys,'/','Stops/Stop detumbling3'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[605,357,770,403])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops/Valeur absolue',13,'des angles2']])
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil  vitesse angulaire')
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles2']],...
		'position',[330,390,465,440])

add_block('built-in/Constant',[sys,'/','Stops/Constant3'])
set_param([sys,'/','Stops/Constant3'],...
		'Value','vitesse_angul_mini',...
		'position',[310,329,480,351])

add_block('built-in/Relational Operator',[sys,'/',['Stops/Relational',13,'Operator1']])
set_param([sys,'/',['Stops/Relational',13,'Operator1']],...
		'position',[505,108,545,257])

add_block('built-in/Relational Operator',[sys,'/',['Stops/Relational',13,'Operator2']])
set_param([sys,'/',['Stops/Relational',13,'Operator2']],...
		'position',[510,303,550,452])

add_block('built-in/Note',[sys,'/','Stops/La'])
set_param([sys,'/','Stops/La'],...
		'position',[205,65,210,70])

add_block('built-in/Note',[sys,'/','Stops/Contrle du seuil angulaire'])
set_param([sys,'/','Stops/Contrle du seuil angulaire'],...
		'ForeGround',1,...
		'position',[680,215,685,220])

add_block('built-in/Note',[sys,'/','Stops/Contrle du seuil de vitesse'])
set_param([sys,'/','Stops/Contrle du seuil de vitesse'],...
		'ForeGround',1,...
		'position',[690,405,695,410])

add_block('built-in/Note',[sys,'/',['Stops/CONTROLEURS DE DEROULEMENT ',13,'']])
set_param([sys,'/',['Stops/CONTROLEURS DE DEROULEMENT ',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[415,25,420,30])
add_line([sys,'/','Stops'],[100,235;120,235])
add_line([sys,'/','Stops'],[200,235;235,235])
add_line([sys,'/','Stops'],[550,185;600,185])
add_line([sys,'/','Stops'],[445,145;500,145])
add_line([sys,'/','Stops'],[435,220;500,220])
add_line([sys,'/','Stops'],[285,220;330,220])
add_line([sys,'/','Stops'],[285,250;300,250;300,415;325,415])
add_line([sys,'/','Stops'],[555,380;600,380])
add_line([sys,'/','Stops'],[470,415;505,415])
add_line([sys,'/','Stops'],[485,340;505,340])
set_param([sys,'/','Stops'],...
		'Mask Display','STOP DE SIMULATION\nSUR SEUIL ANGULAIRE\n( angle mini_mod_fin )')


%     Finished composite block 'Stops'.

set_param([sys,'/','Stops'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'position',[1050,423,1260,477])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[980,295,985,300])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,83,1267,980])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[860,370,930,390])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[410,455,415,460])

add_block('built-in/To File',[sys,'/','Subsystem/To File4'])
set_param([sys,'/','Subsystem/To File4'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'File name','initpqrQ.mat',...
		'Matrix name','initpqrQ',...
		'position',[180,357,335,413])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[985,624,1070,656])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[885,621,965,659])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn5'])
set_param([sys,'/','Subsystem/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[1000,731,1080,769])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace18'])
set_param([sys,'/','Subsystem/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie_relative',...
		'buffer','points_trace',...
		'position',[1100,737,1235,763])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','initpqrQ_final',...
		'buffer','1',...
		'position',[315,292,405,318])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[735,270,740,275])


%     Subsystem  ['Subsystem/ANGLES',13,'EN DEGRES'].

new_system([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/x']])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],[90,65;125,65])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Entries','4000\/-200\/200\/''y-/m--/c-./w+''\/')


%     Finished composite block ['Subsystem/ANGLES',13,'EN DEGRES'].

set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[615,732,705,788])

add_block('built-in/Note',[sys,'/',['Subsystem/Visualisation  l''cran en continu']])
set_param([sys,'/',['Subsystem/Visualisation  l''cran en continu']],...
		'position',[665,820,670,825])

add_block('built-in/Note',[sys,'/',['Subsystem/Stockage de donnes finales',13,'pour d''autres simulations']])
set_param([sys,'/',['Subsystem/Stockage de donnes finales',13,'pour d''autres simulations']],...
		'position',[255,430,260,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[900,550,905,555])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;855,380])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;880,640])
add_line([sys,'/','Subsystem'],[970,640;980,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[1085,750;1095,750])
add_line([sys,'/','Subsystem'],[970,640;970,750;995,750])
add_line([sys,'/','Subsystem'],[440,425;440,385;340,385])
add_line([sys,'/','Subsystem'],[830,465;830,760;710,760])
add_line([sys,'/','Subsystem'],[435,385;435,305;410,305])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES\n\nENERGIE\n\n& TRANSFERT DE initpqrQ')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[1060,294,1265,396])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[805,565,810,570])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[750,640,755,645])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[820,250,855,710])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[755,445,760,450])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[745,311,760,449])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[610,445,630,705])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[90,50,975,400])
open_system([sys,'/','Subsystem4'])

add_block('built-in/Note',[sys,'/','Subsystem4/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'])
set_param([sys,'/','Subsystem4/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'],...
		'ForeGround',3,...
		'BackGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[530,50,535,55])

add_block('built-in/Note',[sys,'/',['Subsystem4/Sortie du couplage',13,'roue satellite']])
set_param([sys,'/',['Subsystem4/Sortie du couplage',13,'roue satellite']],...
		'position',[715,205,720,210])

add_block('built-in/Note',[sys,'/','Subsystem4/Fonction jw_rotot.m'])
set_param([sys,'/','Subsystem4/Fonction jw_rotot.m'],...
		'position',[495,215,500,220])

add_block('built-in/Note',[sys,'/','Subsystem4/pqrQ'])
set_param([sys,'/','Subsystem4/pqrQ'],...
		'position',[200,195,205,200])

add_block('built-in/Note',[sys,'/','Subsystem4/Vitesseroue'])
set_param([sys,'/','Subsystem4/Vitesseroue'],...
		'position',[195,125,200,130])

add_block('built-in/Mux',[sys,'/','Subsystem4/Mux'])
set_param([sys,'/','Subsystem4/Mux'],...
		'inputs','[1 7]',...
		'position',[285,108,340,252])

add_block('built-in/Inport',[sys,'/','Subsystem4/in_1'])
set_param([sys,'/','Subsystem4/in_1'],...
		'position',[235,135,255,155])

add_block('built-in/Inport',[sys,'/','Subsystem4/in_2'])
set_param([sys,'/','Subsystem4/in_2'],...
		'Port','2',...
		'position',[235,205,255,225])

add_block('built-in/Outport',[sys,'/','Subsystem4/out_1'])
set_param([sys,'/','Subsystem4/out_1'],...
		'position',[680,170,700,190])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem4/magneto.m2'])
set_param([sys,'/','Subsystem4/magneto.m2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue\nau second membre')
set_param([sys,'/','Subsystem4/magneto.m2'],...
		'position',[415,156,555,204])

add_block('built-in/Gain',[sys,'/','Subsystem4/Gain1'])
set_param([sys,'/','Subsystem4/Gain1'],...
		'hide name',0,...
		'position',[600,167,625,193])
add_line([sys,'/','Subsystem4'],[345,180;410,180])
add_line([sys,'/','Subsystem4'],[260,145;280,145])
add_line([sys,'/','Subsystem4'],[260,215;280,215])
add_line([sys,'/','Subsystem4'],[560,180;595,180])
add_line([sys,'/','Subsystem4'],[630,180;675,180])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','COUPLAGE ROUE-SATELLITE')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[175,477,415,533])


%     Subsystem  ['Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1']],'Location',[4,166,1267,899])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inport']],...
		'position',[10,485,30,505])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'ForeGround',1)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',18)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[400,35,405,40])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/B']],...
		'position',[480,425,485,430])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[110,515,115,520])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[770,382,805,408])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[850,399,855,404])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[660,277,665,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[740,438,800,472])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[345,315,460,365])

add_block('built-in/To Workspace',[sys,'/',['Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[865,440,985,470])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[215,246,220,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[610,378,670,412])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[510,286,555,504])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[290,288,320,392])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[100,293,245,317])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[100,328,245,352])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[100,363,245,387])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/M']],...
		'position',[495,315,500,320])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[755,318,900,342])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[755,283,900,307])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[755,248,900,272])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[945,243,975,347])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,195,870,200])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[765,158,910,182])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[765,123,910,147])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[765,88,910,112])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[955,83,985,187])


%     Subsystem  ['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[231,269,1077,738])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'position',[190,95,365,145])

add_block('built-in/Clock',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[120,104,155,136])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[280,70,285,75])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/En axes satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/En axes satellite']],...
		'position',[730,220,735,225])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[125,205,130,210])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[145,65,150,70])

add_block('built-in/To Workspace',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']],...
		'hide name',0,...
		'mat-name','BY',...
		'buffer','points_trace',...
		'position',[515,32,565,48])

add_block('built-in/Demux',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux']],...
		'outputs','3',...
		'position',[440,24,480,56])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[370,120;480,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[160,120;185,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[395,120;395,40;435,40])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[485,40;510,40])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[210,458,410,532])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3',...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'position',[600,554,775,606])

add_block('built-in/Sum',[sys,'/',['Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1055,254,1090,361])

add_block('built-in/State-Space',[sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'ForeGround',1,...
		'BackGround',3,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'Mask Type','Matrix Gain',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'position',[1125,288,1195,332])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1225,300,1245,320])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[635,505,640,510])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[695,605,700,610])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[780,580;1020,580;1020,345;1050,345])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[35,495;205,495])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[45,495;45,580;595,580])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[990,135;1040,135;1050,270])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,330;940,330])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[980,295;1050,295])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,295;940,295])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,260;940,260])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,170;950,170])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,135;950,135])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,100;950,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,375;285,375])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,340;285,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,305;285,305])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[325,340;340,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[465,340;505,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[415,495;440,495;440,450;505,450])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[560,395;605,395])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[805,455;860,455])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[675,395;705,395;705,455;735,455])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[705,395;765,395])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[810,395;1005,400;1005,320;1050,320])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[1095,310;1120,310])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[1200,310;1220,310])
set_param([sys,'/',['Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['Perturbations',13,'arodynamiques1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[180,545,415,605])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,930,345])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,732,415,798])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[530,191,1137,462])

add_block('built-in/Note',[sys,'/','Subsystem3/pqr'])
set_param([sys,'/','Subsystem3/pqr'],...
		'ForeGround',1,...
		'position',[190,115,195,120])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/magneto.m1'])
set_param([sys,'/','Subsystem3/magneto.m1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[240,116,375,174])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[30,165,50,185])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'outputs','[3 4]',...
		'position',[90,118,135,227])

add_block('built-in/Note',[sys,'/','Subsystem3/Q'])
set_param([sys,'/','Subsystem3/Q'],...
		'ForeGround',1,...
		'position',[160,180,165,185])

add_block('built-in/Note',[sys,'/','Subsystem3/Q non utilis'])
set_param([sys,'/','Subsystem3/Q non utilis'],...
		'ForeGround',1,...
		'position',[180,210,185,215])

add_block('built-in/Outport',[sys,'/','Subsystem3/out_2'])
set_param([sys,'/','Subsystem3/out_2'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[450,135,470,155])

add_block('built-in/Note',[sys,'/',['Subsystem3/Second membre des quations du TMC',13,'avec les termes de couplage et le rle ',13,'de la roue']])
set_param([sys,'/',['Subsystem3/Second membre des quations du TMC',13,'avec les termes de couplage et le rle ',13,'de la roue']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[290,30,295,35])
add_line([sys,'/','Subsystem3'],[380,145;445,145])
add_line([sys,'/','Subsystem3'],[140,145;235,145])
add_line([sys,'/','Subsystem3'],[55,175;85,175])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','F(X,t)\n\nPOUR LA ROTATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,624,415,696])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[780,805,785,810])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[475,810,480,815])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[220,805,225,810])


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[307,509,1144,814])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain1'])
set_param([sys,'/','Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[220,170,355,210])

add_block('built-in/Sum',[sys,'/','Subsystem5/Sum1'])
set_param([sys,'/','Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain2'])
set_param([sys,'/','Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])


%     Subsystem  'Subsystem5/Subsystem5'.

new_system([sys,'/','Subsystem5/Subsystem5'])
set_param([sys,'/','Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/Outport',[sys,'/','Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem5/Product'])
set_param([sys,'/','Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Clock',[sys,'/','Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','creneau',...
		'buffer','points_trace',...
		'position',[245,178,340,192])
add_line([sys,'/','Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','Subsystem5/Subsystem5'],[205,130;205,185;240,185])
set_param([sys,'/','Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'Subsystem5/Subsystem5'.

set_param([sys,'/','Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/in_1'],...
		'position',[65,100,85,120])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux'])
set_param([sys,'/','Subsystem5/Demux'],...
		'outputs','3',...
		'position',[140,39,180,71])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace2'])
set_param([sys,'/','Subsystem5/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_avant',...
		'buffer','points_trace',...
		'position',[205,38,295,52])

add_block('built-in/Outport',[sys,'/','Subsystem5/out_1'])
set_param([sys,'/','Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_apres',...
		'buffer','points_trace',...
		'position',[650,28,745,42])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux1'])
set_param([sys,'/','Subsystem5/Demux1'],...
		'outputs','3',...
		'position',[585,29,625,61])
add_line([sys,'/','Subsystem5'],[90,110;185,110])
add_line([sys,'/','Subsystem5'],[90,110;125,110;125,190;215,190])
add_line([sys,'/','Subsystem5'],[480,110;520,110])
add_line([sys,'/','Subsystem5'],[360,190;520,190])
add_line([sys,'/','Subsystem5'],[320,110;335,110])
add_line([sys,'/','Subsystem5'],[550,150;630,150])
add_line([sys,'/','Subsystem5'],[185,45;200,45])
add_line([sys,'/','Subsystem5'],[105,110;105,55;135,55])
add_line([sys,'/','Subsystem5'],[630,35;645,35])
add_line([sys,'/','Subsystem5'],[495,110;495,45;580,45])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[565,318,710,372])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[100,287,1055,1136])
open_system([sys,'/','UnNamed1'])

add_block('built-in/Note',[sys,'/','UnNamed1/REGULATION EN "BPOINT" SANS ROUE'])
set_param([sys,'/','UnNamed1/REGULATION EN "BPOINT" SANS ROUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[525,45,530,50])

add_block('built-in/Note',[sys,'/',['UnNamed1/La conservation de l''nergie',13,'']])
set_param([sys,'/',['UnNamed1/La conservation de l''nergie',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[250,435,255,440])

add_block('built-in/Note',[sys,'/',['UnNamed1/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']])
set_param([sys,'/',['UnNamed1/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[505,410,510,415])

add_block('built-in/Note',[sys,'/',['UnNamed1/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']])
set_param([sys,'/',['UnNamed1/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[510,465,515,470])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[125,140,130,145])

add_block('built-in/Note',[sys,'/','UnNamed1/Cette simulation permet de vrifier :'])
set_param([sys,'/','UnNamed1/Cette simulation permet de vrifier :'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[245,390,250,395])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport1'])
set_param([sys,'/','UnNamed1/Inport1'],...
		'hide name',0,...
		'Port','2',...
		'position',[80,305,100,325])

add_block('built-in/Note',[sys,'/',['UnNamed1/Coupure du couple',13,'en mode aprs le  mode Bpoint']])
set_param([sys,'/',['UnNamed1/Coupure du couple',13,'en mode aprs le  mode Bpoint']],...
		'ForeGround',1,...
		'position',[305,313,310,318])

add_block('built-in/Product',[sys,'/','UnNamed1/Product'])
set_param([sys,'/','UnNamed1/Product'],...
		'position',[790,279,820,326])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[455,200,500,230])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[545,192,645,238])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'tous les couples']],...
		'position',[725,155,730,160])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain3'])
set_param([sys,'/','UnNamed1/Gain3'],...
		'hide name',0,...
		'position',[695,198,735,232])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[865,295,885,315])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','test4',...
		'buffer','points_trace',...
		'position',[775,362,825,378])


%     Subsystem  'UnNamed1/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem1'],'Location',[61,122,1222,668])
open_system([sys,'/','UnNamed1/Subsystem1'])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/B''']])
set_param([sys,'/',['UnNamed1/Subsystem1/B''']],...
		'position',[515,190,520,195])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[300,92,305,97])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[95,150,100,155])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/in_1'],...
		'position',[55,235,75,255])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[1025,460,1030,465])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Champ rel'])
set_param([sys,'/','UnNamed1/Subsystem1/Champ rel'],...
		'position',[625,365,630,370])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Puls',13,'linaire']])
set_param([sys,'/',['UnNamed1/Subsystem1/Puls',13,'linaire']],...
		'position',[455,225,460,230])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Pulse crneau'])
set_param([sys,'/','UnNamed1/Subsystem1/Pulse crneau'],...
		'position',[460,195,465,200])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem'],'Location',[480,167,1125,428])
open_system([sys,'/','UnNamed1/Subsystem1/Subsystem'])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/in_1'],...
		'hide name',0,...
		'position',[20,100,40,120])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Champ rel'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Champ rel'],...
		'position',[430,125,435,130])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Champ puls'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Champ puls'],...
		'position',[435,95,440,100])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Drive pulse'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Drive pulse'],...
		'position',[435,65,440,70])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],'Location',[4,301,1154,596])
open_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Vexteur d''tat',13,'7 composantes']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Vexteur d''tat',13,'7 composantes']],...
		'position',[170,60,175,65])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Clock'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Clock'],...
		'position',[150,168,190,202])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/in_1'],...
		'position',[160,115,180,135])


%     Subsystem  ['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[730,190,735,195])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[130,104,165,136])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])
add_line([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],[170,120;245,120])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'position',[240,88,440,162])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Champ rel'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Champ rel'],...
		'position',[870,185,875,190])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Champ puls liss linairement ( mesure )'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Champ puls liss linairement ( mesure )'],...
		'position',[950,140,955,145])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Drive pulse crneau(mesure )'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Drive pulse crneau(mesure )'],...
		'position',[930,100,935,105])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],'Location',[104,238,1049,871])
open_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Gain'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Gain'],...
		'hide name',0,...
		'Gain','pulse_lineaire',...
		'position',[590,383,610,407])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Demux2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Demux2'],...
		'outputs','3',...
		'position',[535,174,580,246])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace14'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace14'],...
		'hide name',0,...
		'mat-name','Bx_cren',...
		'buffer','points_trace',...
		'position',[625,176,705,194])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace13'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace13'],...
		'hide name',0,...
		'mat-name','By_cren',...
		'buffer','points_trace',...
		'position',[625,201,705,219])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace12'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace12'],...
		'hide name',0,...
		'mat-name','Bz_cren',...
		'buffer','points_trace',...
		'position',[625,226,705,244])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace8'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace8'],...
		'hide name',0,...
		'mat-name','Bz_reel',...
		'buffer','points_trace',...
		'position',[770,61,850,79])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace7'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace7'],...
		'hide name',0,...
		'mat-name','By_reel',...
		'buffer','points_trace',...
		'position',[770,36,850,54])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace6'],...
		'hide name',0,...
		'mat-name','Bx_reel',...
		'buffer','points_trace',...
		'position',[770,11,850,29])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Demux'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Demux'],...
		'outputs','3',...
		'position',[680,9,725,81])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Champ  liss'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Champ  liss'],...
		'position',[775,165,780,170])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/out_1'],...
		'Port','3',...
		'position',[790,130,810,150])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Champ rel satellite'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Champ rel satellite'],...
		'position',[585,140,590,145])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Demux1'],...
		'outputs','3',...
		'position',[735,379,780,451])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace9'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace9'],...
		'hide name',0,...
		'mat-name','Bx_pulse',...
		'buffer','points_trace',...
		'position',[825,381,905,399])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace10'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace10'],...
		'hide name',0,...
		'mat-name','By_pulse',...
		'buffer','points_trace',...
		'position',[825,406,905,424])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace11'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace11'],...
		'hide name',0,...
		'mat-name','Bz_pulse',...
		'buffer','points_trace',...
		'position',[825,431,905,449])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/in_1'],...
		'position',[115,310,135,330])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Drive pulse non lisse'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Drive pulse non lisse'],...
		'position',[790,545,795,550])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/out_3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/out_3'],...
		'position',[800,510,820,530])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/out_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/out_2'],...
		'Port','2',...
		'position',[790,265,810,285])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Sum'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Sum'],...
		'hide name',0,...
		'position',[640,254,665,441])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],'Location',[4,50,853,441])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14,...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz '])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz '],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime'],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1'],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT'],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5'],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta'],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/in_1'],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3',...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/To File'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/To File'],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/out_1'],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT'],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)'],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau'],...
		'position',[785,211,790,216])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7'],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],'Location',[125,1114771,765,1115016])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1'],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[175,70,180,75])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],[270,125;290,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],[500,115;520,115])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],[430,145;470,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],[275,165;290,165])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],[325,145;360,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/in_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE/in_2'],...
		'Port','2',...
		'position',[95,250,115,270])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[300,260;370,260])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[130,145;430,145;430,215;450,215])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[365,200;370,200])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[405,230;450,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[490,225;510,225])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[580,225;710,225])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[595,225;595,285;625,285])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[595,225;595,150;630,150])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],[120,260;150,260])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/DERIVEE MESUREE'],...
		'position',[310,380,445,460])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Calcul t-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Calcul t-nT'],...
		'hide name',0,...
		'position',[410,505,415,510])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Product'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Product'],...
		'position',[535,347,560,443])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],'Location',[198,215,1097,749])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Size',14,...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/t-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/t-nT'],...
		'position',[930,355,935,360])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4'],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Clock2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Clock2'],...
		'hide name',0,...
		'position',[45,330,85,370])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],'Location',[163,376,803,621])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[135,100,140,105])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Size',12,...
		'position',[315,0,320,5])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1'],...
		'position',[555,105,575,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],[270,125;290,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],[500,115;550,115])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],[430,145;470,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],[275,165;290,165])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],[325,145;360,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT'],...
		'position',[585,385,590,390])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3'],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/out_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/out_2'],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','torcham(u)',...
		'Output Width','3',...
		'position',[505,213,565,247])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Mux1'],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT'],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau'],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT'],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz '])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz '],...
		'position',[115,180,120,185])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/in_1'],...
		'position',[65,210,85,230])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/out_3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/out_3'],...
		'position',[615,100,635,120])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE/out_1'],...
		'Port','2',...
		'position',[615,220,635,240])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[260,350;285,350;285,430;610,430])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[285,350;370,350])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[480,230;500,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[405,320;430,320;440,235])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[570,230;610,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[590,230;590,280;605,280])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[345,290;370,290])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[90,350;110,350])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[90,350;90,420;135,420])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[90,220;440,220])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],[390,220;390,110;610,110])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/CHAMP MESURE'],...
		'position',[300,285,435,355])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Drive B'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Drive B'],...
		'position',[495,390,500,395])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/derb_chapeau'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/derb_chapeau'],...
		'position',[535,455,540,460])

add_block('built-in/Derivative',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Drive de',13,'B relle']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Drive de',13,'B relle']],...
		'position',[230,382,285,418])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/t -tinj - nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/t -tinj - nT'],...
		'position',[500,345,505,350])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/B(n)'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/B(n)'],...
		'position',[535,295,540,300])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,240,135,245])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Temps'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/Temps'],...
		'position',[130,405,135,410])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/in_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/in_2'],...
		'Port','2',...
		'position',[110,430,130,450])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3/To Workspace5'],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[785,333,905,367])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[615,395;635,395])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[565,395;585,395])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[440,320;580,320;580,300;635,300])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[495,320;495,210;530,210])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[585,235;620,235])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[585,210;620,210])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[585,185;620,185])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[670,350;780,350])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[685,350;685,415;730,415])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[785,440;820,440])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[785,415;820,415])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[785,390;820,390])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[730,70;765,70])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[730,45;765,45])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[730,20;765,20])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[440,295;465,295;465,140;785,140])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[650,140;650,45;675,45])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[140,320;295,320])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[275,320;190,320;190,400;225,400])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[440,345;455,345;455,370;530,370])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[290,400;305,400])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[135,440;305,440])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[450,420;530,420])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[475,420;475,520;795,520])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],[685,350;685,275;785,275])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/Subsystem3'],...
		'hide name',0,...
		'position',[595,97,730,213])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/out_1'],...
		'position',[760,105,780,125])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/out_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/out_2'],...
		'Port','2',...
		'position',[760,145,780,165])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem/out_3'],...
		'Port','3',...
		'position',[760,185,780,205])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],[445,125;590,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],[185,125;235,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],[735,195;755,195])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],[735,155;755,155])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],[735,115;755,115])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],[195,185;590,185])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES + CHAMP REEL')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Subsystem'],...
		'hide name',0,...
		'position',[85,64,285,156])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/out_1'],...
		'hide name',0,...
		'Port','2',...
		'position',[360,100,380,120])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/out_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/out_2'],...
		'hide name',0,...
		'position',[360,70,380,90])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/out_3'],...
		'hide name',0,...
		'Port','3',...
		'position',[360,130,380,150])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[45,110;80,110])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[290,140;355,140])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[290,110;355,110])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[290,80;355,80])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem'],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem'],...
		'position',[145,206,410,284])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']])
set_param([sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']],...
		'MATLAB Fcn','mom_magn(u)',...
		'Output Width','3',...
		'position',[585,248,645,282])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'])
set_param([sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[555,10,560,15])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/B'])
set_param([sys,'/','UnNamed1/Subsystem1/B'],...
		'position',[505,285,510,290])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[525,174,560,356])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[670,195,710,335])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[780,194,810,336])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1075,235,1155,255])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[965,313,1025,347])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[880,202,930,453])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Outport'])
set_param([sys,'/','UnNamed1/Subsystem1/Outport'],...
		'position',[1135,320,1155,340])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace1'],...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[800,90,880,110])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace2'],...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[800,125,880,145])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace3'],...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[800,160,880,180])
add_line([sys,'/','UnNamed1/Subsystem1'],[415,270;450,270;450,390;875,390])
add_line([sys,'/','UnNamed1/Subsystem1'],[415,245;480,245;480,310;520,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[415,220;520,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[1030,330;1030,245;1070,245])
add_line([sys,'/','UnNamed1/Subsystem1'],[1030,330;1130,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[935,330;960,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[565,265;580,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[80,245;140,245])
add_line([sys,'/','UnNamed1/Subsystem1'],[650,265;665,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[815,265;875,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,310;775,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[765,310;765,170;795,170])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,265;775,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[750,265;750,135;795,135])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,220;775,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[730,220;730,100;795,100])
set_param([sys,'/','UnNamed1/Subsystem1'],...
		'Mask Display','REGULATION PAR\n\nDERIVEE DU CHAMP MAGNETIQUE\n\nPULSES')


%     Finished composite block 'UnNamed1/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem1'],...
		'hide name',0,...
		'position',[190,176,420,254])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[75,205,95,225])
add_line([sys,'/','UnNamed1'],[650,215;690,215])
add_line([sys,'/','UnNamed1'],[505,215;540,215])
add_line([sys,'/','UnNamed1'],[425,215;450,215])
add_line([sys,'/','UnNamed1'],[100,215;185,215])
add_line([sys,'/','UnNamed1'],[105,315;785,315])
add_line([sys,'/','UnNamed1'],[740,215;760,215;760,290;785,290])
add_line([sys,'/','UnNamed1'],[825,305;860,305])
add_line([sys,'/','UnNamed1'],[850,305;850,370;830,370])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','COUPLES POUR\n\nTUMBLING "BPOINT"\n\nAVEC CHAMP PULSE',...
		'Mask Type','REGULATION "BPOINT" SANS ROUE',...
		'Mask Help','Bloc pris dans reg_derB en "BPOINT"')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[190,223,420,327])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'position',[435,262,460,288])

add_block('built-in/Switch',[sys,'/','Switch'])
set_param([sys,'/','Switch'],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[490,299,525,391])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[805,335,810,340])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[975,345,980,350])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[900,454,1000,506])

add_block('built-in/Note',[sys,'/','Transmission des valeurs finales au mode acquisition fin'])
set_param([sys,'/','Transmission des valeurs finales au mode acquisition fin'],...
		'BackGround',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[625,155,630,160])
add_line(sys,[860,480;895,480])
add_line(sys,[875,480;875,370;1055,370])
add_line(sys,[140,345;485,345])
add_line(sys,[425,275;430,275])
add_line(sys,[465,275;465,315;485,315])
add_line(sys,[1005,480;1015,480;1015,810;15,810;15,250;185,250])
add_line(sys,[420,765;660,765;660,595;815,595])
add_line(sys,[15,345;25,345])
add_line(sys,[635,575;690,575;690,415;740,415])
add_line(sys,[715,345;740,345])
add_line(sys,[530,345;560,345])
add_line(sys,[1005,480;1015,480;1015,320;1055,320])
add_line(sys,[1015,450;1045,450])
add_line(sys,[140,345;170,300;185,300])
add_line(sys,[15,765;175,765])
add_line(sys,[15,660;175,660])
add_line(sys,[15,575;175,575])
add_line(sys,[15,520;170,520])
add_line(sys,[420,660;605,660])
add_line(sys,[420,575;605,575])
add_line(sys,[420,505;560,505;560,490;605,490])
add_line(sys,[765,380;790,380;790,365;815,365])
add_line(sys,[160,490;170,490])
add_line(sys,[425,375;485,375])
add_line(sys,[370,355;385,355])
add_line(sys,[370,375;385,375])
add_line(sys,[370,395;385,395])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
