function [ret,x0,str,ts,xts]=regderb2(t,x,u,flag);
%REGDERB2	is the M-file description of the SIMULINK system named REGDERB2.
%	The block-diagram can be displayed by typing: REGDERB2.
%
%	SYS=REGDERB2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGDERB2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGDERB2 with a FLAG of zero:
%	[SIZES]=REGDERB2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,61,1267,988])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '30000')
set_param(sys,'Min step size', '0.5')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'PHASE DE DETUMBLING']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'PHASE DE DETUMBLING']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[678,0,683,5])

add_block('built-in/Note',[sys,'/',['SIMULATION regderb2.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur q - w0 et tangage )']])
set_param([sys,'/',['SIMULATION regderb2.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur q - w0 et tangage )']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['SIMULATION regderb2.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur q - w0 et tangage )']],...
		'Font Size',18,...
		'position',[625,60,630,65])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[670,145,675,150])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, my, mz',...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[380,695,605,756])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[635,780,810,846])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[130,695,330,761])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[375,765,605,851])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[475,640,480,645])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[655,575,660,580])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[245,580,250,585])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[430,555,435,560])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[485,310,490,315])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[475,490,480,495])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,438,400,542])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[560,274,620,561])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[685,394,785,446])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[580,325,585,330])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[575,465,580,470])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[850,325,855,330])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[850,260,855,265])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance derivdat.m']])
set_param([sys,'/',['L''initialisation',13,' lance derivdat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1165,430,1170,435])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,50,1267,977])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Note',[sys,'/','Subsystem/Vrifications Poinsot'])
set_param([sys,'/','Subsystem/Vrifications Poinsot'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[965,295,970,300])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Note',[sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']])
set_param([sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']],...
		'position',[235,230,240,235])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  mettre un stop'])
set_param([sys,'/','Subsystem/Reste  mettre un stop'],...
		'position',[235,205,240,210])

add_block('built-in/Note',[sys,'/',['Subsystem/Mettre une saturation',13,'',13,'']])
set_param([sys,'/',['Subsystem/Mettre une saturation',13,'',13,'']],...
		'position',[230,255,235,260])

add_block('built-in/Note',[sys,'/','Subsystem/Mettre des filtres'])
set_param([sys,'/','Subsystem/Mettre des filtres'],...
		'position',[225,310,230,315])

add_block('built-in/Note',[sys,'/','Subsystem/Mettre des retards'])
set_param([sys,'/','Subsystem/Mettre des retards'],...
		'position',[230,280,235,285])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope'])
set_param([sys,'/','Subsystem/Scope'],...
		'Vgain','0.004000',...
		'Hgain','50000.000000',...
		'Vmax','0.008000',...
		'Hmax','100000.000000',...
		'Window',[314,357,1072,908],...
		'position',[865,130,895,160])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[930,624,1015,656])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;795,285])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;925,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[685,210;685,145;860,145])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[905,301,1100,374])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[117,336,1099,1003])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[235,250,240,255])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[290,390,295,395])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[155,218,200,482])

add_block('built-in/Note',[sys,'/','UnNamed1/p q r'])
set_param([sys,'/','UnNamed1/p q r'],...
		'position',[290,460,295,465])


%     Subsystem  'UnNamed1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem'],'Location',[138,337,1183,1003])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Quaternion'])
set_param([sys,'/','UnNamed1/Subsystem/Quaternion'],...
		'position',[200,160,205,165])


%     Subsystem  'UnNamed1/Subsystem/Subsystem2'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2'],'Location',[4,50,1267,977])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace3'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[685,500,765,520])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace2'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[685,470,765,490])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace1'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[685,440,765,460])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Demux1'],...
		'orientation',2,...
		'outputs','3',...
		'position',[795,435,845,525])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Gain pour',13,'avoir le bon signe',13,'des produits vectoriels']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Gain pour',13,'avoir le bon signe',13,'des produits vectoriels']],...
		'position',[475,160,480,165])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem2/Gain5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Gain5'],...
		'Gain','-1',...
		'position',[450,216,485,244])


%     Subsystem  'UnNamed1/Subsystem/Subsystem2/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],'Location',[4,50,1267,977])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Subsystem/B',13,'axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Subsystem/B',13,'axes satellite']],...
		'position',[500,110,505,115])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','quatbmgn(u)',...
		'Output Width','3',...
		'position',[410,77,475,113])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/( B,Q )'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/( B,Q )'],...
		'position',[380,70,385,75])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Clock'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Clock'],...
		'position',[60,55,80,75])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Mux2'],...
		'inputs','[3 4]',...
		'position',[320,39,350,146])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[110,40,285,90])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/out_1'],...
		'position',[525,85,545,105])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/in_1'],...
		'position',[60,110,80,130])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[355,95;405,95])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[290,65;315,65])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[85,65;105,65])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[480,95;520,95])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[85,120;315,120])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],...
		'Mask Display','CHAMP MAGNETIQUE\nEN AXES SATELLITE\nA PARTIR DU CHAMP \nEN AXES ORBITAUX\nET DU QUATERNION D''ATTITUDE')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem2/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],...
		'hide name',0,...
		'position',[140,232,350,328])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem2/Gain4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Gain4'],...
		'Gain','0',...
		'position',[230,376,265,404])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Demux'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Demux'],...
		'outputs','3',...
		'position',[145,345,195,435])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Mux'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Mux'],...
		'inputs','3',...
		'position',[295,344,325,436])


%     Subsystem  ['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire'].

new_system([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_2']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Sum']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Product']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[150,65;180,65])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[95,65;120,65])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[40,35;60,60])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[40,100;60,70])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire'].

set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],...
		'position',[405,321,420,414])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/omega*'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/omega*'],...
		'position',[360,365,365,370])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u/(norm(u))^2',...
		'Output Width','3',...
		'Mask Display','B/norm(B)')
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn2'],...
		'position',[400,260,485,300])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Rotationtransversale',13,'de px+rz']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Rotationtransversale',13,'de px+rz']],...
		'inputs','-+',...
		'position',[570,264,595,511])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem/Subsystem2/Product'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Product'],...
		'position',[505,236,540,414])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/B'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/B'],...
		'position',[380,255,385,260])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem2/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/in_1'],...
		'position',[85,270,105,290])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem2/in_2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/in_2'],...
		'Port','2',...
		'position',[85,380,105,400])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem/Subsystem2/',13,'mux']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/',13,'mux']],...
		'inputs','[3 3]',...
		'position',[630,268,660,432])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[675,332,740,368])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Moment',13,'magntique']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Moment',13,'magntique']],...
		'position',[710,370,715,375])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem2/gain_magneto'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/gain_magneto'],...
		'Gain','1e6',...
		'position',[775,376,810,404])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem2/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/out_1'],...
		'position',[1175,340,1195,360])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1075,332,1140,368])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Mux3'],...
		'inputs','[3 3]',...
		'position',[1005,268,1035,432])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1060,255,1140,275])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','saturmom(u)',...
		'Output Width','3',...
		'Mask Display','LIMITEUR\nPROPORTIONNEL\nA 0.2 Am')
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn5'],...
		'position',[835,368,965,412])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/M (3 )_'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/M (3 )_'],...
		'position',[990,360,995,365])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/B ( 3 )'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/B ( 3 )'],...
		'position',[975,280,980,285])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Couple',13,'magntique']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Couple',13,'magntique']],...
		'position',[1105,295,1110,300])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Produit vectoriel',13,'M, B']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Produit vectoriel',13,'M, B']],...
		'position',[1105,370,1110,375])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/CALCUL DU COUPLE MAGNETIQUE BASE SUR LA DERIVEE DE B',13,'CONCERNANT UNIQUEMENT LE ROULIS ET LE TANGAGE']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/CALCUL DU COUPLE MAGNETIQUE BASE SUR LA DERIVEE DE B',13,'CONCERNANT UNIQUEMENT LE ROULIS ET LE TANGAGE']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/CALCUL DU COUPLE MAGNETIQUE BASE SUR LA DERIVEE DE B',13,'CONCERNANT UNIQUEMENT LE ROULIS ET LE TANGAGE']],...
		'Font Size',18,...
		'position',[635,50,640,55])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[745,350;755,350;755,390;770,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[1145,350;1170,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[1155,350;1145,265])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[790,510;770,510])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[790,480;770,480])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[790,450;770,450])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[1040,350;1070,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[490,230;615,230;625,310])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[615,230;736,230;735,310;1000,310])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[355,280;395,280])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[370,280;370,230;445,230])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[665,350;670,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[600,390;625,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[330,390;400,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[360,390;360,450;565,450])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[545,325;565,325])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[490,280;500,280])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[425,370;500,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[365,280;365,345;400,345])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[200,420;290,420])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[200,360;290,360])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[270,390;290,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[200,390;225,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[110,280;135,280])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[110,390;140,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[815,390;830,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[970,390;1000,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[990,390;990,480;850,480])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2'],...
		'Mask Display','CONTRLE\nPAR MAGNETOCOUPLEURS\n\nDES COMPOSANTES p,  r')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem2'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem2'],...
		'hide name',0,...
		'position',[270,165,475,245])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem/Couple total'])
set_param([sys,'/','UnNamed1/Subsystem/Couple total'],...
		'position',[605,144,630,391])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Subsystem/out_3'],...
		'hide name',0,...
		'position',[670,260,690,280])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/p q r'])
set_param([sys,'/','UnNamed1/Subsystem/p q r'],...
		'position',[200,245,205,250])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Rotation'])
set_param([sys,'/','UnNamed1/Subsystem/Rotation'],...
		'position',[200,225,205,230])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/in_1'],...
		'hide name',0,...
		'position',[85,173,105,197])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_2'])
set_param([sys,'/','UnNamed1/Subsystem/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[90,215,110,235])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Rappel sur l''intgrale de q qui',13,'devrait reprsenter sensiblement',13,'l''angle de tangage']])
set_param([sys,'/',['UnNamed1/Subsystem/Rappel sur l''intgrale de q qui',13,'devrait reprsenter sensiblement',13,'l''angle de tangage']],...
		'position',[800,40,805,45])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Test d''arrt']])
set_param([sys,'/',['UnNamed1/Subsystem/Test d''arrt']],...
		'position',[805,100,810,105])


%     Subsystem  'UnNamed1/Subsystem/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1'],'Location',[188,389,1095,933])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem1/COMMANDE DE LA ROUE DE TANGAGE'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/COMMANDE DE LA ROUE DE TANGAGE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[485,25,490,30])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,' la',13,'rotation q-w0']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,' la',13,'rotation q-w0']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[500,75,505,80])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Mux4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Mux4'],...
		'hide name',0,...
		'inputs','3',...
		'position',[505,157,540,273])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,'au',13,'tangage']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,'au',13,'tangage']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[360,440,365,445])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Mux5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[505,312,540,428])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace6'],...
		'hide name',0,...
		'mat-name','cpl_roue_teta',...
		'buffer','points_trace',...
		'position',[405,340,485,360])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain10'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain10'],...
		'hide name',0,...
		'Gain','0',...
		'position',[305,316,340,344])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain9'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain9'],...
		'hide name',0,...
		'Gain','0',...
		'position',[305,396,340,424])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain8'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain8'],...
		'hide name',0,...
		'Gain','-4e-6',...
		'position',[295,352,375,388])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem1/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[115,353,175,387])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem1/Roue'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Roue'],...
		'hide name',0,...
		'position',[275,110,280,115])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/in_1'],...
		'hide name',0,...
		'position',[75,205,95,225])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Demux3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Demux3'],...
		'hide name',0,...
		'outputs','3',...
		'position',[135,157,175,273])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain6'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain6'],...
		'hide name',0,...
		'Gain','0',...
		'position',[215,161,250,189])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem1/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/out_1'],...
		'hide name',0,...
		'position',[830,305,850,325])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem/Subsystem1/Sum'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Sum'],...
		'hide name',0,...
		'position',[640,267,685,358])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem1/in_2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[65,360,85,380])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Demux4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[195,312,235,428])

add_block('built-in/Saturation',[sys,'/','UnNamed1/Subsystem/Subsystem1/Saturation'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Saturation'],...
		'Lower Limit','-4e-6',...
		'Upper Limit','4e-6',...
		'position',[740,303,770,327])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem1/Limiteur couple',13,'roue  4e-6 Nn']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem1/Limiteur couple',13,'roue  4e-6 Nn']],...
		'position',[765,350,770,355])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace4'],...
		'hide name',0,...
		'mat-name','cpl_roue',...
		'buffer','points_trace',...
		'position',[825,265,905,285])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain7'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain7'],...
		'hide name',0,...
		'Gain','0',...
		'position',[430,241,465,269])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/gain_roue'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/gain_roue'],...
		'hide name',0,...
		'Gain','-1e-3',...
		'position',[325,190,395,240])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem/Subsystem1/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Sum1'],...
		'inputs','+-',...
		'position',[265,206,280,239])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem/Subsystem1/Constant'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Constant'],...
		'Value','vitesse_rotation',...
		'position',[185,217,230,243])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace5'],...
		'hide name',0,...
		'mat-name','cpl_roue_q',...
		'buffer','points_trace',...
		'position',[415,190,495,210])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,255;425,255])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[255,175;500,175])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,175;210,175])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[470,255;500,255])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[100,215;130,215])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[90,370;110,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,370;190,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[240,370;290,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[345,330;500,330])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[345,410;500,410])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[380,370;500,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[240,330;300,330])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[240,410;300,410])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[545,370;625,370;635,335])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[400,215;500,215])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[545,215;560,215;560,290;635,290])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[390,370;400,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[690,315;735,315])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[775,315;825,315])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[790,315;790,275;820,275])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[400,215;410,200])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,215;260,215])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[235,230;260,230])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[285,225;295,225;295,215;320,215])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1'],...
		'Mask Display','COUPLE ROUE\n\nSUR LE TANGAGE\n\nSEUL')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem1'],...
		'hide name',0,...
		'position',[270,283,480,372])
add_line([sys,'/','UnNamed1/Subsystem'],[110,185;265,185])
add_line([sys,'/','UnNamed1/Subsystem'],[115,225;265,225])
add_line([sys,'/','UnNamed1/Subsystem'],[635,270;665,270])
add_line([sys,'/','UnNamed1/Subsystem'],[480,205;600,205])
add_line([sys,'/','UnNamed1/Subsystem'],[155,225;155,305;265,305])
add_line([sys,'/','UnNamed1/Subsystem'],[485,330;600,330])
add_line([sys,'/','UnNamed1/Subsystem'],[126,185;125,350;265,350])
set_param([sys,'/','UnNamed1/Subsystem'],...
		'Mask Display','ACQUISITION ROUE\n+\nUN MAGNETOCOUPLEUR\nSUR\nLE TANGAGE')


%     Finished composite block 'UnNamed1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem'],...
		'position',[330,390,515,485])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'inputs','+++',...
		'position',[635,53,675,517])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[705,272,730,298])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[775,275,795,295])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'Gain','0',...
		'position',[450,117,475,143])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,207,1271,813])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[250,102,380,158])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[65,120,85,140])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[75,55,80,60])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[345,259,470,311])
add_line([sys,'/','UnNamed1'],[385,130;445,130])
add_line([sys,'/','UnNamed1'],[205,285;340,285])
add_line([sys,'/','UnNamed1'],[735,285;770,285])
add_line([sys,'/','UnNamed1'],[90,130;245,130])
add_line([sys,'/','UnNamed1'],[135,130;135,350;150,350])
add_line([sys,'/','UnNamed1'],[205,415;325,415])
add_line([sys,'/','UnNamed1'],[253,285;253,460;325,460])
add_line([sys,'/','UnNamed1'],[520,440;630,440])
add_line([sys,'/','UnNamed1'],[475,285;630,285])
add_line([sys,'/','UnNamed1'],[480,130;630,130])
add_line([sys,'/','UnNamed1'],[680,285;700,285])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,303,410,387])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[640,700,815,756])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[855,695,1030,761])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''derivdat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[870,425,1085,496])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[10,115,1238,841])
open_system([sys,'/','Subsystem1'])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION regderb2'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION regderb2'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem1/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem1/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[865,550,1215,586])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[559,482,1161,775])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[690,263,775,317])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[90,258,125,292])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[135,785,340,846])
add_line(sys,[790,420;810,420;810,575;100,575;100,490;180,490])
add_line(sys,[625,420;680,420])
add_line(sys,[415,345;555,345])
add_line(sys,[405,490;555,490])
add_line(sys,[810,420;810,320;900,320])
add_line(sys,[660,420;660,355;900,355])
add_line(sys,[100,490;100,345;180,345])
add_line(sys,[810,320;810,290;780,290])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
