function [ret,x0,str,ts,xts]=ttpulse1(t,x,u,flag);
%TTPULSE1	is the M-file description of the SIMULINK system named TTPULSE1.
%	The block-diagram can be displayed by typing: TTPULSE1.
%
%	SYS=TTPULSE1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes TTPULSE1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling TTPULSE1 with a FLAG of zero:
%	[SIZES]=TTPULSE1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,78,1267,975])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','n')

add_block('built-in/Note',[sys,'/',['SIMULATION TOTALE1.M DEVANT FINIR CASAASAT.m',13,'']])
set_param([sys,'/',['SIMULATION TOTALE1.M DEVANT FINIR CASAASAT.m',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[700,60,705,65])

add_block('built-in/Note',[sys,'/','Hcheur'])
set_param([sys,'/','Hcheur'],...
		'position',[655,245,660,250])


%     Subsystem  'Graphiques'.

new_system([sys,'/','Graphiques'])
set_param([sys,'/','Graphiques'],'Location',[25,6553675,1165,6554120])


%     Subsystem  'Graphiques/Extras27'.

new_system([sys,'/','Graphiques/Extras27'])
set_param([sys,'/','Graphiques/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras27'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r,temps,switch_long/10);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras27'.

set_param([sys,'/','Graphiques/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[15,240,220,301])


%     Subsystem  'Graphiques/Extras22'.

new_system([sys,'/','Graphiques/Extras22'])
set_param([sys,'/','Graphiques/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras22'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras22'.

set_param([sys,'/','Graphiques/Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,310,225,371])


%     Subsystem  'Graphiques/Extras29'.

new_system([sys,'/','Graphiques/Extras29'])
set_param([sys,'/','Graphiques/Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras29'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras29'.

set_param([sys,'/','Graphiques/Extras29'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,325,480,381])


%     Subsystem  'Graphiques/Extras21'.

new_system([sys,'/','Graphiques/Extras21'])
set_param([sys,'/','Graphiques/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras21'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras21'.

set_param([sys,'/','Graphiques/Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,235,710,301])


%     Subsystem  'Graphiques/Extras20'.

new_system([sys,'/','Graphiques/Extras20'])
set_param([sys,'/','Graphiques/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras20'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras20'.

set_param([sys,'/','Graphiques/Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[510,315,710,381])

add_block('built-in/Note',[sys,'/','Graphiques/SORTIES GRAPHIQUES'])
set_param([sys,'/','Graphiques/SORTIES GRAPHIQUES'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[525,50,530,55])


%     Subsystem  'Graphiques/Extras30'.

new_system([sys,'/','Graphiques/Extras30'])
set_param([sys,'/','Graphiques/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras30'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras30'.

set_param([sys,'/','Graphiques/Extras30'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,160,710,216])


%     Subsystem  'Graphiques/Extras34'.

new_system([sys,'/','Graphiques/Extras34'])
set_param([sys,'/','Graphiques/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras34'],...
		'Mask Display','Voir courbe\nchangement\nde rgulation',...
		'Mask Dialogue','eval(''plot(temps,switch_long);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras34'.

set_param([sys,'/','Graphiques/Extras34'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,315,1100,381])


%     Subsystem  'Graphiques/Extras32'.

new_system([sys,'/','Graphiques/Extras32'])
set_param([sys,'/','Graphiques/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras32'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras32'.

set_param([sys,'/','Graphiques/Extras32'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,235,1100,301])


%     Subsystem  'Graphiques/Extras23'.

new_system([sys,'/','Graphiques/Extras23'])
set_param([sys,'/','Graphiques/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras23'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet,temps,switch_long*100);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras23'.

set_param([sys,'/','Graphiques/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,155,220,221])


%     Subsystem  'Graphiques/Extras24'.

new_system([sys,'/','Graphiques/Extras24'])
set_param([sys,'/','Graphiques/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras24'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras24'.

set_param([sys,'/','Graphiques/Extras24'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,165,910,231])


%     Subsystem  'Graphiques/Extras25'.

new_system([sys,'/','Graphiques/Extras25'])
set_param([sys,'/','Graphiques/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras25'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras25'.

set_param([sys,'/','Graphiques/Extras25'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,240,910,306])


%     Subsystem  'Graphiques/Extras26'.

new_system([sys,'/','Graphiques/Extras26'])
set_param([sys,'/','Graphiques/Extras26'],'Location',[4,50,1012,686])
set_param([sys,'/','Graphiques/Extras26'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Graphiques/Extras26'.

set_param([sys,'/','Graphiques/Extras26'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,225,475,311])


%     Subsystem  'Graphiques/Extras28'.

new_system([sys,'/','Graphiques/Extras28'])
set_param([sys,'/','Graphiques/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras28'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx_deriv, my_deriv, mz_deriv')
set_param([sys,'/','Graphiques/Extras28'],...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv,temps,switch_long*0.2);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras28'.

set_param([sys,'/','Graphiques/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,155,490,216])


%     Subsystem  'Graphiques/Extras31'.

new_system([sys,'/','Graphiques/Extras31'])
set_param([sys,'/','Graphiques/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras31'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue,temps,switch_long*4e-6);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras31'.

set_param([sys,'/','Graphiques/Extras31'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,160,1100,226])


%     Subsystem  'Graphiques/Extras33'.

new_system([sys,'/','Graphiques/Extras33'])
set_param([sys,'/','Graphiques/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphiques/Extras33'],...
		'Mask Display','Voir courbe\ncomposantes\n\n By et BY du champ',...
		'Mask Dialogue','eval(''plot(temps,BY,temps,By);grid;figure(gcf)'')')


%     Finished composite block 'Graphiques/Extras33'.

set_param([sys,'/','Graphiques/Extras33'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,310,905,386])
set_param([sys,'/','Graphiques'],...
		'Mask Display','SORTIES|\n\nGRAPHIQUES')


%     Finished composite block 'Graphiques'.

set_param([sys,'/','Graphiques'],...
		'position',[1275,730,1530,786])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[900,419,1000,471])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[975,310,980,315])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[805,300,810,305])

add_block('built-in/Switch',[sys,'/','Switch'])
set_param([sys,'/','Switch'],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[490,264,525,356])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,255,1177,806])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/To Workspace1'])
set_param([sys,'/','UnNamed4/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cx',...
		'buffer','points_trace',...
		'position',[855,287,905,303])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/To Workspace2'])
set_param([sys,'/','UnNamed4/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cy',...
		'buffer','points_trace',...
		'position',[855,322,905,338])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/To Workspace3'])
set_param([sys,'/','UnNamed4/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cz',...
		'buffer','points_trace',...
		'position',[860,357,910,373])

add_block('built-in/Note',[sys,'/','UnNamed4/REGULATION EN ACQUISITION GROSSIERE OU FINE'])
set_param([sys,'/','UnNamed4/REGULATION EN ACQUISITION GROSSIERE OU FINE'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[570,20,575,25])

add_block('built-in/Product',[sys,'/','UnNamed4/Product'])
set_param([sys,'/','UnNamed4/Product'],...
		'position',[555,414,585,461])

add_block('built-in/Note',[sys,'/',['UnNamed4/Coupure du calcul',13,'couple roue en mode Bpoint']])
set_param([sys,'/',['UnNamed4/Coupure du calcul',13,'couple roue en mode Bpoint']],...
		'ForeGround',1,...
		'position',[280,475,285,480])

add_block('built-in/Gain',[sys,'/','UnNamed4/Gain7'])
set_param([sys,'/','UnNamed4/Gain7'],...
		'hide name',0,...
		'position',[750,427,775,453])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/To Workspace7'])
set_param([sys,'/','UnNamed4/To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[665,389,770,421])

add_block('built-in/Gain',[sys,'/','UnNamed4/Gain2'])
set_param([sys,'/','UnNamed4/Gain2'],...
		'hide name',0,...
		'position',[655,202,680,228])


%     Subsystem  'UnNamed4/Subsystem'.

new_system([sys,'/','UnNamed4/Subsystem'])
set_param([sys,'/','UnNamed4/Subsystem'],'Location',[506,195,1156,577])

add_block('built-in/Gain',[sys,'/',['UnNamed4/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['UnNamed4/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'ForeGround',2,...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem/Gain3'])
set_param([sys,'/','UnNamed4/Subsystem/Gain3'],...
		'ForeGround',2,...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem/To Workspace5'])
set_param([sys,'/','UnNamed4/Subsystem/To Workspace5'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['UnNamed4/Subsystem/Vitesse roue ',13,'en rd//s']],...
		'ForeGround',2,...
		'position',[520,210,525,215])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem/in_1'])
set_param([sys,'/','UnNamed4/Subsystem/in_1'],...
		'ForeGround',2,...
		'position',[20,125,40,145])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['UnNamed4/Subsystem/Vitesse roue',13,'en tours//mn']],...
		'ForeGround',2,...
		'position',[455,70,460,75])

add_block('built-in/Gain',[sys,'/',['UnNamed4/Subsystem/Inertie',13,'de la ',13,'roue']])
set_param([sys,'/',['UnNamed4/Subsystem/Inertie',13,'de la ',13,'roue']],...
		'ForeGround',2,...
		'BackGround',7,...
		'Gain','1/jroue',...
		'position',[195,115,230,155])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem/SUIVI DE LA ROUE'])
set_param([sys,'/','UnNamed4/Subsystem/SUIVI DE LA ROUE'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[390,10,395,15])

add_block('built-in/Integrator',[sys,'/','UnNamed4/Subsystem/Integrator2'])
set_param([sys,'/','UnNamed4/Subsystem/Integrator2'],...
		'ForeGround',2,...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[280,113,325,157])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem/To Workspace6'])
set_param([sys,'/','UnNamed4/Subsystem/To Workspace6'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[445,179,590,211])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem/Sortie de la vitesse ',13,'de la roue']])
set_param([sys,'/',['UnNamed4/Subsystem/Sortie de la vitesse ',13,'de la roue']],...
		'position',[485,325,490,330])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem/out_1'])
set_param([sys,'/','UnNamed4/Subsystem/out_1'],...
		'hide name',0,...
		'position',[610,330,630,350])

add_block('built-in/To File',[sys,'/','UnNamed4/Subsystem/To File'])
set_param([sys,'/','UnNamed4/Subsystem/To File'],...
		'ForeGround',2,...
		'File name','vit_roue.mat',...
		'Matrix name','vit_roue_rd_s',...
		'position',[455,247,570,273])
add_line([sys,'/','UnNamed4/Subsystem'],[475,135;510,135])
add_line([sys,'/','UnNamed4/Subsystem'],[150,135;190,135])
add_line([sys,'/','UnNamed4/Subsystem'],[45,135;110,135])
add_line([sys,'/','UnNamed4/Subsystem'],[235,135;275,135])
add_line([sys,'/','UnNamed4/Subsystem'],[330,135;440,135])
add_line([sys,'/','UnNamed4/Subsystem'],[395,135;395,195;440,195])
add_line([sys,'/','UnNamed4/Subsystem'],[395,195;395,345;605,340])
add_line([sys,'/','UnNamed4/Subsystem'],[420,195;420,260;450,260])
set_param([sys,'/','UnNamed4/Subsystem'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'UnNamed4/Subsystem'.

set_param([sys,'/','UnNamed4/Subsystem'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[855,409,1000,471])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant'])
set_param([sys,'/','UnNamed4/Constant'],...
		'position',[380,415,400,435])

add_block('built-in/Sum',[sys,'/','UnNamed4/Sum1'])
set_param([sys,'/','UnNamed4/Sum1'],...
		'inputs','+-',...
		'position',[440,401,470,499])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_2'])
set_param([sys,'/','UnNamed4/out_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[1055,430,1075,450])

add_block('built-in/Note',[sys,'/','UnNamed4/Sortie vitesseroue'])
set_param([sys,'/','UnNamed4/Sortie vitesseroue'],...
		'position',[1070,465,1075,470])

add_block('built-in/Note',[sys,'/',['UnNamed4/Somme des couples',13,'externes1']])
set_param([sys,'/',['UnNamed4/Somme des couples',13,'externes1']],...
		'ForeGround',1,...
		'position',[1000,160,1005,165])

add_block('built-in/Note',[sys,'/',['UnNamed4/Sorties des commande en',13,'axes satellite x y z']])
set_param([sys,'/',['UnNamed4/Sorties des commande en',13,'axes satellite x y z']],...
		'position',[990,320,995,325])


%     Subsystem  'UnNamed4/Subsystem3'.

new_system([sys,'/','UnNamed4/Subsystem3'])
set_param([sys,'/','UnNamed4/Subsystem3'],'Location',[4,129,1267,1003])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/in_1'])
set_param([sys,'/','UnNamed4/Subsystem3/in_1'],...
		'position',[15,310,30,330])


%     Subsystem  ['UnNamed4/Subsystem3/Inner',13,'Product'].

new_system([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/in_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/Sum']])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/Product']])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],[150,65;180,65])
add_line([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],[40,100;60,70])
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['UnNamed4/Subsystem3/Inner',13,'Product'].

set_param([sys,'/',['UnNamed4/Subsystem3/Inner',13,'Product']],...
		'position',[450,479,475,526])

add_block('built-in/Demux',[sys,'/','UnNamed4/Subsystem3/Demux4'])
set_param([sys,'/','UnNamed4/Subsystem3/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[440,234,480,336])

add_block('built-in/Demux',[sys,'/','UnNamed4/Subsystem3/Demux5'])
set_param([sys,'/','UnNamed4/Subsystem3/Demux5'],...
		'hide name',0,...
		'outputs','3',...
		'position',[440,354,480,456])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed4/Subsystem3/MATLAB Fcn'])
set_param([sys,'/','UnNamed4/Subsystem3/MATLAB Fcn'],...
		'MATLAB Fcn','saturmm(u)',...
		'Output Width','3',...
		'position',[780,323,840,357])

add_block('built-in/Demux',[sys,'/','UnNamed4/Subsystem3/Demux2'])
set_param([sys,'/','UnNamed4/Subsystem3/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[860,301,900,379])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/To Workspace'])
set_param([sys,'/','UnNamed4/Subsystem3/To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[960,383,1005,397])

add_block('built-in/Product',[sys,'/','UnNamed4/Subsystem3/Product2'])
set_param([sys,'/','UnNamed4/Subsystem3/Product2'],...
		'position',[670,477,700,513])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/mz'])
set_param([sys,'/','UnNamed4/Subsystem3/mz'],...
		'position',[680,335,685,340])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Cr'])
set_param([sys,'/','UnNamed4/Subsystem3/Cr'],...
		'position',[680,450,685,455])

add_block('built-in/Product',[sys,'/','UnNamed4/Subsystem3/Product'])
set_param([sys,'/','UnNamed4/Subsystem3/Product'],...
		'position',[665,277,695,313])

add_block('built-in/Product',[sys,'/','UnNamed4/Subsystem3/Product1'])
set_param([sys,'/','UnNamed4/Subsystem3/Product1'],...
		'position',[665,362,695,398])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/To Workspace1'])
set_param([sys,'/','UnNamed4/Subsystem3/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[940,197,990,213])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Gain'])
set_param([sys,'/','UnNamed4/Subsystem3/Gain'],...
		'Gain','-1',...
		'position',[510,357,535,383])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Cx Cy Cz'])
set_param([sys,'/','UnNamed4/Subsystem3/Cx Cy Cz'],...
		'position',[370,500,375,505])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed4/Subsystem3/MATLAB Fcn1'])
set_param([sys,'/','UnNamed4/Subsystem3/MATLAB Fcn1'],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1095,418,1155,452])

add_block('built-in/Mux',[sys,'/','UnNamed4/Subsystem3/Mux2'])
set_param([sys,'/','UnNamed4/Subsystem3/Mux2'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[1045,365,1075,500])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Moment cr par',13,'magntocoupleurs']])
set_param([sys,'/',['UnNamed4/Subsystem3/Moment cr par',13,'magntocoupleurs']],...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[1120,315,1125,320])

add_block('built-in/Mux',[sys,'/','UnNamed4/Subsystem3/Mux1'])
set_param([sys,'/','UnNamed4/Subsystem3/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[980,228,1010,362])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Moments magntiques',13,'des bobines']])
set_param([sys,'/',['UnNamed4/Subsystem3/Moments magntiques',13,'des bobines']],...
		'position',[780,220,785,225])

add_block('built-in/Constant',[sys,'/','UnNamed4/Subsystem3/Constant'])
set_param([sys,'/','UnNamed4/Subsystem3/Constant'],...
		'hide name',0,...
		'Value','0',...
		'position',[940,285,960,305])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE'])
set_param([sys,'/','UnNamed4/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE'],...
		'ForeGround',3,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[660,10,665,15])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Champ magntique'])
set_param([sys,'/','UnNamed4/Subsystem3/Champ magntique'],...
		'position',[340,280,345,285])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/1//By'])
set_param([sys,'/','UnNamed4/Subsystem3/1//By'],...
		'position',[530,230,535,235])

add_block('built-in/Mux',[sys,'/','UnNamed4/Subsystem3/Mux'])
set_param([sys,'/','UnNamed4/Subsystem3/Mux'],...
		'inputs','3',...
		'position',[735,273,765,407])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed4/Subsystem3/MATLAB Fcn3'])
set_param([sys,'/','UnNamed4/Subsystem3/MATLAB Fcn3'],...
		'MATLAB Fcn','1/u',...
		'Output Width','1',...
		'position',[525,268,585,302])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']])
set_param([sys,'/',['UnNamed4/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[605,60,610,65])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/To Workspace2'])
set_param([sys,'/','UnNamed4/Subsystem3/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','By',...
		'buffer','points_trace',...
		'position',[535,187,585,203])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Limiteur de',13,'moments magntiques',13,'et de couple roue']])
set_param([sys,'/',['UnNamed4/Subsystem3/Limiteur de',13,'moments magntiques',13,'et de couple roue']],...
		'position',[835,395,840,400])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Outport'])
set_param([sys,'/','UnNamed4/Subsystem3/Outport'],...
		'position',[1185,425,1205,445])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/COUPLE ROUE ',13,'DIMENSION 1',13,'EXERCE PAR LA ROUE SUR LE SATELLITE']])
set_param([sys,'/',['UnNamed4/Subsystem3/COUPLE ROUE ',13,'DIMENSION 1',13,'EXERCE PAR LA ROUE SUR LE SATELLITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1000,540,1005,545])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Outport1'])
set_param([sys,'/','UnNamed4/Subsystem3/Outport1'],...
		'Port','2',...
		'position',[1170,515,1190,535])


%     Subsystem  'UnNamed4/Subsystem3/Subsystem'.

new_system([sys,'/','UnNamed4/Subsystem3/Subsystem'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem'],'Location',[14,50,1124,953])


%     Subsystem  'UnNamed4/Subsystem3/Subsystem/Subsystem4'.

new_system([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],'Location',[54,436,663,791])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Ecart teta_ref - teta'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Ecart teta_ref - teta'],...
		'ForeGround',1,...
		'position',[80,40,85,45])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem4/Vitesse',13,'tangage']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem4/Vitesse',13,'tangage']],...
		'ForeGround',1,...
		'position',[70,185,75,190])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/in_2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/in_2'],...
		'ForeGround',1,...
		'Port','2',...
		'position',[50,140,70,160])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/commande_pid'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/commande_pid'],...
		'ForeGround',1,...
		'position',[555,140,575,160])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Gain2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Gain2'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','gain_tangage',...
		'position',[375,129,430,171])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Filtre passe bas'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Filtre passe bas'],...
		'ForeGround',1,...
		'BackGround',0,...
		'Denominator','[1 1/0.8]',...
		'position',[455,125,515,175])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/ROUE'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/ROUE'],...
		'ForeGround',1,...
		'hide name',0,...
		'position',[239,75,244,80])

add_block('built-in/Sum',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Sum'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Sum'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[325,42,355,258])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Intgrateur'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Intgrateur'],...
		'ForeGround',1,...
		'BackGround',7,...
		'Numerator','[I_PID_TANGAGE]',...
		'Denominator','[1 0]',...
		'position',[155,199,225,241])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/in_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/in_1'],...
		'ForeGround',1,...
		'position',[55,70,75,90])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Gain'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Gain'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_TANGAGE',...
		'position',[160,61,235,99])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/gain 0 ou 1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/gain 0 ou 1'],...
		'ForeGround',1,...
		'Gain','0',...
		'position',[255,207,285,233])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Rappel proportionnel'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Rappel proportionnel'],...
		'ForeGround',1,...
		'position',[190,95,195,100])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Gain1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4/Gain1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_TANGAGE',...
		'position',[165,129,220,171])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[75,150;160,150])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[435,150;450,150])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[360,150;370,150])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[80,80;155,80])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[110,80;110,220;150,220])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[520,150;550,150])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[240,80;320,80])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[225,150;320,150])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[230,220;250,220])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],[290,220;320,220])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],...
		'Mask Display','P.I.D TANGAGE')


%     Finished composite block 'UnNamed4/Subsystem3/Subsystem/Subsystem4'.

set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[515,329,660,396])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Angles  rd',13,'et',13,'vitesses']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Angles  rd',13,'et',13,'vitesses']],...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[70,393,130,427])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/entre pqr',13,'et',13,' Q']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/entre pqr',13,'et',13,' Q']],...
		'position',[50,340,55,345])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/in_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/in_1'],...
		'position',[30,400,50,420])


%     Subsystem  'UnNamed4/Subsystem3/Subsystem/Subsystem2'.

new_system([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],'Location',[70,50,922,463])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/roulisref - roulis '])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/roulisref - roulis '],...
		'ForeGround',1,...
		'position',[275,135,280,140])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem2/Vitesse ',13,'roulis']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem2/Vitesse ',13,'roulis']],...
		'ForeGround',1,...
		'position',[260,280,265,285])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/in_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/in_1'],...
		'ForeGround',1,...
		'position',[255,165,275,185])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/in_2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/in_2'],...
		'ForeGround',1,...
		'Port','2',...
		'position',[250,235,270,255])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/PID ROULIS'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/PID ROULIS'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[510,70,515,75])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem2/Rappel',13,'proportionnel']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem2/Rappel',13,'proportionnel']],...
		'ForeGround',1,...
		'position',[465,140,470,145])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Rappel proportionnel'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Rappel proportionnel'],...
		'ForeGround',1,...
		'position',[400,190,405,195])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/gain 0 ou 1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/gain 0 ou 1'],...
		'ForeGround',1,...
		'Gain','0.5*0',...
		'position',[465,302,495,328])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Gain'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Gain'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_ROULIS',...
		'position',[370,156,445,194])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Intgrateur'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Intgrateur'],...
		'ForeGround',1,...
		'BackGround',7,...
		'Numerator','[I_PID_ROULIS]',...
		'Denominator','[1 0]',...
		'position',[350,294,435,336])

add_block('built-in/Sum',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Sum'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Sum'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[535,137,565,353])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/ROUE'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/ROUE'],...
		'ForeGround',1,...
		'hide name',0,...
		'position',[449,170,454,175])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/out_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/out_1'],...
		'ForeGround',1,...
		'position',[775,235,795,255])

add_block('built-in/Transfer Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem2/Filtre passe bas',13,'roulis']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem2/Filtre passe bas',13,'roulis']],...
		'ForeGround',1,...
		'BackGround',0,...
		'Denominator','[1 1/0.8]',...
		'position',[680,220,740,270])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Gain2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Gain2'],...
		'ForeGround',1,...
		'BackGround',7,...
		'Gain','gain_roulis',...
		'position',[595,232,620,258])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Gain1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2/Gain1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_ROULIS',...
		'position',[380,224,435,266])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[275,245;375,245])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[280,175;365,175])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[315,175;315,315;345,315])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[570,245;590,245])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[625,245;675,245])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[450,175;530,175])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[440,245;530,245])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[440,315;460,315])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[500,315;530,315])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],[745,245;770,245])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],...
		'Mask Display','PID ROULIS SEUL')


%     Finished composite block 'UnNamed4/Subsystem3/Subsystem/Subsystem2'.

set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[515,215,665,270])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Roulis',13,'lacet']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Roulis',13,'lacet']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[545,195,550,200])

add_block('built-in/Constant',[sys,'/','UnNamed4/Subsystem3/Subsystem/Constant3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Constant3'],...
		'hide name',0,...
		'Value','consigne_lacet',...
		'position',[250,332,360,358])

add_block('built-in/Sum',[sys,'/','UnNamed4/Subsystem3/Subsystem/Sum4'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[380,329,400,391])

add_block('built-in/Constant',[sys,'/','UnNamed4/Subsystem3/Subsystem/Constant2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Constant2'],...
		'hide name',0,...
		'Value','consigne_tangage',...
		'position',[245,267,355,293])

add_block('built-in/Sum',[sys,'/','UnNamed4/Subsystem3/Subsystem/Sum3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Sum3'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[380,264,400,326])

add_block('built-in/Sum',[sys,'/','UnNamed4/Subsystem3/Subsystem/Sum1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[380,202,400,258])

add_block('built-in/Constant',[sys,'/','UnNamed4/Subsystem3/Subsystem/Constant1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Constant1'],...
		'hide name',0,...
		'Value','consigne_roulis',...
		'position',[250,202,360,228])

add_block('built-in/Demux',[sys,'/','UnNamed4/Subsystem3/Subsystem/Demux1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Demux1'],...
		'hide name',0,...
		'outputs','6',...
		'position',[180,213,220,602])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor avec consigne-angle et gain - sur les angles  )']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor avec consigne-angle et gain - sur les angles  )']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor avec consigne-angle et gain - sur les angles  )']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor avec consigne-angle et gain - sur les angles  )']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor avec consigne-angle et gain - sur les angles  )']],...
		'Font Size',20)
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor avec consigne-angle et gain - sur les angles  )']],...
		'position',[540,5,545,10])


%     Subsystem  'UnNamed4/Subsystem3/Subsystem/Subsystem3'.

new_system([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],'Location',[180,417,870,782])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem3/Vitesse',13,'lacet',13,'']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem3/Vitesse',13,'lacet',13,'']],...
		'ForeGround',1,...
		'position',[115,270,120,275])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/in_2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/in_2'],...
		'ForeGround',1,...
		'Port','2',...
		'position',[110,190,130,210])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/PID LACET'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/PID LACET'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[335,20,340,25])

add_block('built-in/Transfer Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem3/Filtre passe bas',13,'lacet']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem3/Filtre passe bas',13,'lacet']],...
		'ForeGround',1,...
		'BackGround',0,...
		'Denominator','[1 1/0.8]',...
		'position',[485,175,545,225])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Gain4'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Gain4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'Gain','gain_lacet',...
		'position',[440,187,465,213])

add_block('built-in/Inport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/in_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/in_1'],...
		'ForeGround',1,...
		'position',[115,120,135,140])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/out_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/out_1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[580,190,600,210])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/ROUE1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/ROUE1'],...
		'ForeGround',1,...
		'hide name',0,...
		'position',[294,125,299,130])

add_block('built-in/Sum',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Sum1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Sum1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[380,92,410,308])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Intgrateur1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Intgrateur1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'Numerator','[I_PID_LACET]',...
		'Denominator','[1 0]',...
		'position',[210,249,280,291])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Gain2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Gain2'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_LACET',...
		'position',[215,111,290,149])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/gain 0 ou 2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/gain 0 ou 2'],...
		'ForeGround',1,...
		'Gain','0.5*0',...
		'position',[310,257,340,283])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Rappel proportionnel1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Rappel proportionnel1'],...
		'ForeGround',1,...
		'position',[245,145,250,150])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/lacet_ref - lacet  '])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/lacet_ref - lacet  '],...
		'ForeGround',1,...
		'position',[125,90,130,95])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem3/Rappel',13,'proportionnel1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Subsystem3/Rappel',13,'proportionnel1']],...
		'ForeGround',1,...
		'position',[315,75,320,80])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Gain3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3/Gain3'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_LACET',...
		'position',[225,179,280,221])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[135,200;220,200])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[415,200;435,200])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[470,200;480,200])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[550,200;575,200])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[345,270;375,270])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[285,270;305,270])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[285,200;375,200])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[295,130;375,130])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[140,130;210,130])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],[190,130;165,130;165,270;205,270])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],...
		'Mask Display','PID LACET SEUL')


%     Finished composite block 'UnNamed4/Subsystem3/Subsystem/Subsystem3'.

set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Subsystem3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[510,440,660,495])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Consigne-Angles'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Consigne-Angles'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[295,155,300,160])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_teta',...
		'buffer','points_trace',...
		'position',[800,537,850,553])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_psi',...
		'buffer','points_trace',...
		'position',[795,502,845,518])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/out_3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/out_3'],...
		'Port','3',...
		'position',[860,420,880,440])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/NB : cette simulation rcupre angles et vitesses angulaires directelent avec p q r Q sans utiliser du//dt'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/NB : cette simulation rcupre angles et vitesses angulaires directelent avec p q r Q sans utiliser du//dt'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/NB : cette simulation rcupre angles et vitesses angulaires directelent avec p q r Q sans utiliser du//dt'],...
		'position',[545,115,550,120])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Champ B axes satellite'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Champ B axes satellite'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[810,560,815,565])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[875,275,880,280])

add_block('built-in/Mux',[sys,'/','UnNamed4/Subsystem3/Subsystem/Mux3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Mux3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[810,367,835,493])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_phi',...
		'buffer','points_trace',...
		'position',[795,237,845,253])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace4'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace4'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[315,403,410,417])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Gain1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Gain1'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[335,426,405,454])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace5'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[320,468,415,482])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Gain3'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Gain3'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[340,493,400,517])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace6'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[350,538,445,552])

add_block('built-in/Gain',[sys,'/','UnNamed4/Subsystem3/Subsystem/Gain2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Gain2'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[345,558,405,582])

add_block('built-in/Mux',[sys,'/','UnNamed4/Subsystem3/Subsystem/Mux5'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[315,593,345,697])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Angles'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Angles'],...
		'position',[300,700,305,705])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/out_2'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/out_2'],...
		'Port','2',...
		'position',[880,720,900,740])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[885,670,890,675])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[215,30,220,35])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[60,160,65,165])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[105,135,110,140])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[740,145,745,150])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[45,115,65,135])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[180,85,355,135])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'position',[590,234,665,266])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'position',[600,104,665,136])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/Mux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/State-Space',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/',...
		'position',[415,338,470,372])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'position',[615,349,675,391])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Mux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/State-Space',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Mux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Demux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/State-Space',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Clock',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[35,100,55,120])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_2']],...
		'Port','2',...
		'position',[960,405,980,425])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sortie du temps simulation']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sortie du temps simulation']],...
		'position',[960,375,965,380])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[60,110;175,110])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[75,110;75,415;955,415])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[160,86,285,164])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[655,110,690,140])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/out_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/out_2']],...
		'Port','2',...
		'position',[660,210,695,240])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],'Location',[195,84,1140,549])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Temps']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Temps']],...
		'position',[130,285,135,290])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/To Workspace',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/To Workspace5']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/To Workspace5']],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[730,213,850,247])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Drive pulse non lisse']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Drive pulse non lisse']],...
		'position',[805,330,810,335])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Champ  liss']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Champ  liss']],...
		'position',[845,115,850,120])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Champ rel satellite']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Champ rel satellite']],...
		'position',[810,55,815,60])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/B(n)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/B(n)']],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/t -tinj - nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/t -tinj - nT']],...
		'position',[500,225,505,230])

add_block('built-in/Derivative',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Drive de',13,'B relle']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/derb_chapeau']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/derb_chapeau']],...
		'position',[535,335,540,340])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Drive B']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Drive B']],...
		'position',[495,270,500,275])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],'Location',[115,469,1014,1003])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/t-nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/t-nT']],...
		'position',[930,355,935,360])

add_block('built-in/To Workspace',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/To Workspace4']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/To Workspace4']],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Clock',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Clock2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Clock2']],...
		'hide name',0,...
		'position',[45,330,85,370])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],'Location',[125,659,765,904])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/in_1']],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Sum4']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Sum1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],[270,125;290,125])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],[345,145;345,85;470,85])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Subsystem']],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Sortie de to = t -tinj - nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Sortie de to = t -tinj - nT']],...
		'position',[585,385,590,390])

add_block('built-in/Constant',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Constant1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/To Workspace',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/To Workspace3']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/To Workspace3']],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/out_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/out_2']],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Partie',13,'entire n1']],...
		'position',[505,213,565,247])

add_block('built-in/Mux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Mux1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Mux1']],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/t - tinj- nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/t - tinj- nT']],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Sortie champ B chapeau']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Sortie champ B chapeau']],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Calcul t-nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Calcul t-nT']],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Entre de B(t) //xyz ']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/Entre de B(t) //xyz ']],...
		'position',[115,180,120,185])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/in_1']],...
		'position',[65,210,85,230])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/out_3']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/out_3']],...
		'position',[615,100,635,120])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE/out_1']],...
		'Port','2',...
		'position',[615,220,635,240])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[260,350;285,350;285,430;610,430])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[285,350;370,350])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[90,220;440,220])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[480,230;500,230])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[570,230;610,230])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[405,320;430,320;440,235])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[590,230;590,280;605,280])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[345,290;370,290])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[90,350;110,350])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[90,350;90,420;135,420])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],[390,220;390,110;610,110])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/CHAMP MESURE']],...
		'position',[300,165,435,235])

add_block('built-in/Product',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Product']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Product']],...
		'position',[535,227,560,323])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Calcul t-nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Calcul t-nT']],...
		'hide name',0,...
		'position',[410,385,415,390])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],'Location',[4,50,853,441])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Size',12,...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14)
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Entre de dB//dt //xyz ']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Entre de dB//dt //xyz ']],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Sortie B_prime']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Sortie B_prime']],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Mux1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Mux1']],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/t--tinj -nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/t--tinj -nT']],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Constant1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/To Workspace',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/To Workspace5']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/To Workspace5']],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/t-tinj -nT<=Ta']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/t-tinj -nT<=Ta']],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/in_1']],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/To File']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/To File']],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/out_1']],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Sortie de t-tinj-nT']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Sortie de t-tinj-nT']],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/B(n)']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/B(n)']],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_chapeau']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/derb_chapeau']],...
		'position',[785,211,790,216])

add_block('built-in/To Workspace',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/To Workspace7']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/To Workspace7']],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])


%     Subsystem  ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem'].

new_system([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],'Location',[125,1114771,765,1115016])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/in_1']],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Sum4']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Sum1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],[270,125;290,125])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],[345,145;345,85;470,85])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Subsystem']],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/in_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE/in_2']],...
		'Port','2',...
		'position',[95,250,115,270])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[300,260;370,260])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[130,145;430,145;430,215;450,215])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[365,200;370,200])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[405,230;450,230])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[490,225;510,225])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[580,225;710,225])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[595,225;595,285;625,285])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[595,225;595,150;630,150])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],[120,260;150,260])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/DERIVEE MESUREE']],...
		'position',[310,260,445,340])

add_block('built-in/Sum',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Sum']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/Sum']],...
		'hide name',0,...
		'position',[640,134,665,321])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/out_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/out_1']],...
		'position',[465,165,485,185])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/out_3']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/out_3']],...
		'Port','3',...
		'position',[475,290,495,310])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/in_1']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/in_1']],...
		'position',[140,190,160,210])

add_block('built-in/Inport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/in_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/in_2']],...
		'Port','2',...
		'position',[180,310,200,330])

add_block('built-in/Outport',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/out_2']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem/out_2']],...
		'Port','2',...
		'position',[690,145,710,165])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[165,200;295,200])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[275,200;190,200;190,280;225,280])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[440,200;580,200;580,180;635,180])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[440,225;455,225;455,250;530,250])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[450,300;530,300])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[670,230;725,230])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[565,275;635,275])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[290,280;305,280])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[440,175;460,175])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[670,230;685,155])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[450,300;470,300])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],[205,320;305,320])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Subsystem']],...
		'hide name',0,...
		'position',[340,86,465,164])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Drive non',13,'utilise']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Drive non',13,'utilise']],...
		'position',[510,140,515,145])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Champ mesur liss']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Champ mesur liss']],...
		'position',[575,95,580,100])

add_block('built-in/Note',[sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Sortie champ magntique rel',13,'utilis pour le calcul des moments',13,'magntiques']])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Sortie champ magntique rel',13,'utilis pour le calcul des moments',13,'magntiques']],...
		'position',[675,260,680,265])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[70,125;155,125])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[290,105;335,105])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[290,145;335,145])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[470,125;650,125])
add_line([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[470,100;555,100;555,225;655,225])
set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],...
		'position',[550,610,750,685])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/out_1'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/out_1'],...
		'position',[875,620,895,640])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Subsystem/Champ magntique rel'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/Champ magntique rel'],...
		'position',[890,815,895,820])

add_block('built-in/Outport',[sys,'/','UnNamed4/Subsystem3/Subsystem/out_4'])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem/out_4'],...
		'Port','4',...
		'position',[885,780,905,800])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[665,365;695,365;695,445;780,445;780,430;805,430])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[405,295;485,295;485,345;510,345])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[405,360;430,360;430,455;505,455])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[405,230;510,230])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,375;375,375])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[365,345;375,345])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,310;375,310])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[360,280;375,280])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[365,215;375,215])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,245;375,245])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[135,410;175,410])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[55,410;65,410])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[725,445;725,545;795,545])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[665,470;805,470])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[760,470;760,510;790,510])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[755,630;870,630])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[840,430;855,430])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,440;330,440])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[410,440;450,440;450,255;510,255])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,505;335,505])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[405,505;420,505;420,380;510,380])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,570;340,570])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[410,570;455,570;455,480;505,480])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[350,645;545,650])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[522,650;520,730;875,730])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[670,245;790,245])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[770,245;770,390;805,390])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[295,440;295,410;310,410])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[295,505;295,475;315,475])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[300,570;300,545;345,545])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[225,245;225,610;310,610])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[245,310;245,645;310,645])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[265,375;265,680;310,680])
add_line([sys,'/','UnNamed4/Subsystem3/Subsystem'],[755,665;795,665;795,790;880,790])
set_param([sys,'/','UnNamed4/Subsystem3/Subsystem'],...
		'Mask Display','CALCUL DES COUPLES PID\nSUR AXES DE MESURE\nDES ANGLES DE CARDAN')


%     Finished composite block 'UnNamed4/Subsystem3/Subsystem'.

set_param([sys,'/','UnNamed4/Subsystem3/Subsystem'],...
		'position',[50,271,230,374])

add_block('built-in/Mux',[sys,'/','UnNamed4/Subsystem3/Mux4'])
set_param([sys,'/','UnNamed4/Subsystem3/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[265,292,305,363])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed4/Subsystem3/MATLAB Fcn2'])
set_param([sys,'/','UnNamed4/Subsystem3/MATLAB Fcn2'],...
		'MATLAB Fcn','CpidToCm(u)',...
		'Output Width','3',...
		'position',[330,313,390,347])

add_block('built-in/Note',[sys,'/','UnNamed4/Subsystem3/Champ magntique rel servant au calcul des couples '])
set_param([sys,'/','UnNamed4/Subsystem3/Champ magntique rel servant au calcul des couples '],...
		'position',[420,575,425,580])
add_line([sys,'/','UnNamed4/Subsystem3'],[35,320;45,325])
add_line([sys,'/','UnNamed4/Subsystem3'],[700,295;730,295])
add_line([sys,'/','UnNamed4/Subsystem3'],[310,330;325,330])
add_line([sys,'/','UnNamed4/Subsystem3'],[1160,435;1180,435])
add_line([sys,'/','UnNamed4/Subsystem3'],[235,285;435,285])
add_line([sys,'/','UnNamed4/Subsystem3'],[420,285;420,490;445,490])
add_line([sys,'/','UnNamed4/Subsystem3'],[1080,435;1090,435])
add_line([sys,'/','UnNamed4/Subsystem3'],[905,340;975,340])
add_line([sys,'/','UnNamed4/Subsystem3'],[940,340;940,390;955,390])
add_line([sys,'/','UnNamed4/Subsystem3'],[905,315;935,315;935,250;975,250])
add_line([sys,'/','UnNamed4/Subsystem3'],[920,315;920,205;935,205])
add_line([sys,'/','UnNamed4/Subsystem3'],[965,295;975,295])
add_line([sys,'/','UnNamed4/Subsystem3'],[705,495;710,495;710,385;730,385])
add_line([sys,'/','UnNamed4/Subsystem3'],[700,380;710,380;710,340;730,340])
add_line([sys,'/','UnNamed4/Subsystem3'],[845,340;855,340])
add_line([sys,'/','UnNamed4/Subsystem3'],[770,340;775,340])
add_line([sys,'/','UnNamed4/Subsystem3'],[480,505;665,505])
add_line([sys,'/','UnNamed4/Subsystem3'],[395,330;425,330;435,405])
add_line([sys,'/','UnNamed4/Subsystem3'],[405,330;405,515;445,515])
add_line([sys,'/','UnNamed4/Subsystem3'],[540,370;660,370])
add_line([sys,'/','UnNamed4/Subsystem3'],[485,370;505,370])
add_line([sys,'/','UnNamed4/Subsystem3'],[485,440;585,440;585,305;660,305])
add_line([sys,'/','UnNamed4/Subsystem3'],[235,335;260,345])
add_line([sys,'/','UnNamed4/Subsystem3'],[235,310;260,310])
add_line([sys,'/','UnNamed4/Subsystem3'],[1015,295;1025,295;1025,400;1040,400])
add_line([sys,'/','UnNamed4/Subsystem3'],[485,285;520,285])
add_line([sys,'/','UnNamed4/Subsystem3'],[590,285;660,285])
add_line([sys,'/','UnNamed4/Subsystem3'],[620,285;620,485;665,485])
add_line([sys,'/','UnNamed4/Subsystem3'],[620,390;660,390])
add_line([sys,'/','UnNamed4/Subsystem3'],[500,285;500,195;530,195])
add_line([sys,'/','UnNamed4/Subsystem3'],[905,365;915,365;915,525;1165,525])
add_line([sys,'/','UnNamed4/Subsystem3'],[235,360;255,360;255,570;800,570;800,465;1040,465])
set_param([sys,'/','UnNamed4/Subsystem3'],...
		'Mask Display','COMMANDE 2 AXES ROULIS-LACET\n\nAVEC 2 BOBINES ROULIS-LACET\n\nCOMMANDE TANGAGE SEUL PAR ROUE')


%     Finished composite block 'UnNamed4/Subsystem3'.

set_param([sys,'/','UnNamed4/Subsystem3'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[140,177,460,273])

add_block('built-in/Product',[sys,'/','UnNamed4/Product1'])
set_param([sys,'/','UnNamed4/Product1'],...
		'position',[570,189,600,236])

add_block('built-in/Inport',[sys,'/','UnNamed4/Inport'])
set_param([sys,'/','UnNamed4/Inport'],...
		'hide name',0,...
		'Port','2',...
		'position',[35,215,55,235])

add_block('built-in/Note',[sys,'/',['UnNamed4/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed4/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[105,95,110,100])

add_block('built-in/Note',[sys,'/',['UnNamed4/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']])
set_param([sys,'/',['UnNamed4/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']],...
		'ForeGround',1,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['UnNamed4/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']],...
		'position',[1040,240,1045,245])

add_block('built-in/Note',[sys,'/',['UnNamed4/Suppression possible',13,'de tous les couples']])
set_param([sys,'/',['UnNamed4/Suppression possible',13,'de tous les couples']],...
		'ForeGround',1,...
		'position',[990,245,995,250])

add_block('built-in/Gain',[sys,'/','UnNamed4/Gain4'])
set_param([sys,'/','UnNamed4/Gain4'],...
		'hide name',0,...
		'position',[970,192,995,218])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'hide name',0,...
		'position',[1025,195,1045,215])

add_block('built-in/State-Space',[sys,'/',['UnNamed4/Inverse',13,'matrice',13,'satellite']])
set_param([sys,'/',['UnNamed4/Inverse',13,'matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed4/Inverse',13,'matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[805,182,905,228])

add_block('built-in/Note',[sys,'/',['UnNamed4/Couple exerc par la  roue sur ',13,'le satellite']])
set_param([sys,'/',['UnNamed4/Couple exerc par la  roue sur ',13,'le satellite']],...
		'ForeGround',1,...
		'position',[690,450,695,455])

add_block('built-in/Demux',[sys,'/','UnNamed4/Demux1'])
set_param([sys,'/','UnNamed4/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[785,280,830,390])

add_block('built-in/Sum',[sys,'/','UnNamed4/Sum'])
set_param([sys,'/','UnNamed4/Sum'],...
		'position',[750,95,775,315])

add_block('built-in/Inport',[sys,'/','UnNamed4/Inport1'])
set_param([sys,'/','UnNamed4/Inport1'],...
		'hide name',0,...
		'position',[40,465,60,485])

add_block('built-in/To Workspace',[sys,'/','UnNamed4/To Workspace4'])
set_param([sys,'/','UnNamed4/To Workspace4'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','test_basculement',...
		'buffer','points_trace',...
		'position',[185,418,350,442])
add_line([sys,'/','UnNamed4'],[780,205;800,205])
add_line([sys,'/','UnNamed4'],[910,205;965,205])
add_line([sys,'/','UnNamed4'],[1000,205;1020,205])
add_line([sys,'/','UnNamed4'],[60,225;135,225])
add_line([sys,'/','UnNamed4'],[835,300;850,295])
add_line([sys,'/','UnNamed4'],[835,335;850,330])
add_line([sys,'/','UnNamed4'],[835,370;855,365])
add_line([sys,'/','UnNamed4'],[780,440;850,440])
add_line([sys,'/','UnNamed4'],[465,250;535,250;535,425;550,425])
add_line([sys,'/','UnNamed4'],[65,475;435,475])
add_line([sys,'/','UnNamed4'],[475,450;550,450])
add_line([sys,'/','UnNamed4'],[405,425;435,425])
add_line([sys,'/','UnNamed4'],[590,440;745,440])
add_line([sys,'/','UnNamed4'],[685,215;695,215;695,335;780,335])
add_line([sys,'/','UnNamed4'],[465,200;565,200])
add_line([sys,'/','UnNamed4'],[605,215;650,215])
add_line([sys,'/','UnNamed4'],[490,450;490,225;565,225])
add_line([sys,'/','UnNamed4'],[1005,440;1050,440])
add_line([sys,'/','UnNamed4'],[695,215;695,150;745,150])
add_line([sys,'/','UnNamed4'],[590,440;625,440;625,260;745,260])
add_line([sys,'/','UnNamed4'],[625,405;660,405])
add_line([sys,'/','UnNamed4'],[155,475;155,430;180,430])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','COUPLES POUR\n\nACQUISITION')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[190,315,425,410])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'position',[435,227,460,253])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[86,120,1041,657])

add_block('built-in/Note',[sys,'/','UnNamed1/REGULATION EN "BPOINT" SANS ROUE'])
set_param([sys,'/','UnNamed1/REGULATION EN "BPOINT" SANS ROUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[525,45,530,50])

add_block('built-in/Note',[sys,'/',['UnNamed1/La conservation de l''nergie',13,'']])
set_param([sys,'/',['UnNamed1/La conservation de l''nergie',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[250,435,255,440])

add_block('built-in/Note',[sys,'/',['UnNamed1/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']])
set_param([sys,'/',['UnNamed1/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[505,410,510,415])

add_block('built-in/Note',[sys,'/',['UnNamed1/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']])
set_param([sys,'/',['UnNamed1/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[510,465,515,470])


%     Subsystem  'UnNamed1/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem1'],'Location',[17,208,1259,754])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[1070,455,1075,460])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Outport'])
set_param([sys,'/','UnNamed1/Subsystem1/Outport'],...
		'position',[1145,320,1165,340])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1140,235,1220,255])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/B''']])
set_param([sys,'/',['UnNamed1/Subsystem1/B''']],...
		'position',[595,190,600,195])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/B'])
set_param([sys,'/','UnNamed1/Subsystem1/B'],...
		'position',[590,285,595,290])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[610,174,645,356])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[755,195,795,335])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[865,194,895,336])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1050,313,1110,347])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[965,202,1015,453])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']])
set_param([sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']],...
		'MATLAB Fcn','mom_magn(u)',...
		'Output Width','3',...
		'position',[665,248,725,282])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace1'],...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[885,90,965,110])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace2'],...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[885,125,965,145])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace3'],...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[885,160,965,180])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Champ rel interagissant avec les bobines'])
set_param([sys,'/','UnNamed1/Subsystem1/Champ rel interagissant avec les bobines'],...
		'position',[675,390,680,395])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[85,395,90,400])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ B puls',13,'linaris']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ B puls',13,'linaris']],...
		'position',[515,290,520,295])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE PULSEE NON LINEARISEE DE B ET UN GAIN MATRICIEL'])
set_param([sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE PULSEE NON LINEARISEE DE B ET UN GAIN MATRICIEL'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[615,0,620,5])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui  rgnant  la position du satellite'])
set_param([sys,'/','UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui  rgnant  la position du satellite'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[390,42,395,47])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Ici le champ et sa drive sont dduits des mesures ( B linaris et B'' non linarise ) ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Ici le champ et sa drive sont dduits des mesures ( B linaris et B'' non linarise ) ']],...
		'ForeGround',2,...
		'Font Size',14,...
		'position',[435,65,440,70])


%     Subsystem  ['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/out_2']],...
		'Port','2',...
		'position',[705,265,725,285])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie du temps',13,'simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Sortie du temps',13,'simulation']],...
		'position',[710,305,715,310])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[165,104,200,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[260,95,435,145])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[120,190,140,210])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[205,120;255,120])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[440,120;480,120])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[145,200;480,200])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],[232,120;230,275;700,275])
set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['UnNamed1/Subsystem1/Champ magntique',13,'en axes satellite_']],...
		'position',[50,175,215,250])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem'],'Location',[4,50,1013,479])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Temps'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Temps'],...
		'position',[130,285,135,290])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/To Workspace5'],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','20000',...
		'position',[730,213,850,247])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Drive pulse non lisse'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Drive pulse non lisse'],...
		'position',[805,330,810,335])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Champ  liss'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Champ  liss'],...
		'position',[845,115,850,120])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Champ rel satellite'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Champ rel satellite'],...
		'position',[810,55,815,60])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/B(n)'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/B(n)'],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/t -tinj - nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/t -tinj - nT'],...
		'position',[500,225,505,230])

add_block('built-in/Derivative',[sys,'/',['UnNamed1/Subsystem1/Subsystem/Drive de',13,'B relle']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/derb_chapeau'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/derb_chapeau'],...
		'position',[535,335,540,340])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Drive B'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Drive B'],...
		'position',[495,270,500,275])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],'Location',[115,469,1014,1003])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/t-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/t-nT'],...
		'position',[930,355,935,360])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/To Workspace4'],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Clock2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Clock2'],...
		'hide name',0,...
		'position',[45,330,85,370])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],'Location',[125,659,765,904])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/out_1'],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Constant4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Sum4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[175,70,180,75])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],[270,125;290,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],[500,115;520,115])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],[430,145;470,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],[275,165;290,165])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],[325,145;360,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Subsystem'],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Sortie de to = t -tinj - nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Sortie de to = t -tinj - nT'],...
		'position',[585,385,590,390])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/To Workspace3'],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/out_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/out_2'],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3',...
		'position',[505,213,565,247])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Mux1'],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/t - tinj- nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/t - tinj- nT'],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Sortie champ B chapeau'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Sortie champ B chapeau'],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Calcul t-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Calcul t-nT'],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Entre de B(t) //xyz '])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/Entre de B(t) //xyz '],...
		'position',[115,180,120,185])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/in_1'],...
		'position',[65,210,85,230])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/out_3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/out_3'],...
		'position',[615,100,635,120])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE/out_1'],...
		'Port','2',...
		'position',[615,220,635,240])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[260,350;285,350;285,430;610,430])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[285,350;370,350])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[90,220;440,220])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[480,230;500,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[570,230;610,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[405,320;430,320;440,235])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[590,230;590,280;605,280])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[345,290;370,290])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[90,350;110,350])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[90,350;90,420;135,420])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],[390,220;390,110;610,110])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/CHAMP MESURE'],...
		'position',[300,165,435,235])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem1/Subsystem/Product'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Product'],...
		'position',[535,227,560,323])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/Calcul t-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Calcul t-nT'],...
		'hide name',0,...
		'position',[410,385,415,390])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],'Location',[4,50,853,441])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure'],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14,...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Entre de dB//dt //xyz '])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Entre de dB//dt //xyz '],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Sortie B_prime'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Sortie B_prime'],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Mux1'],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/t--tinj -nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/t--tinj -nT'],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Constant1'],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/To Workspace5'],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/t-tinj -nT<=Ta'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/t-tinj -nT<=Ta'],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/in_1'],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3',...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/To File'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/To File'],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/out_1'],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Sortie de t-tinj-nT'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Sortie de t-tinj-nT'],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/B(n)'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/B(n)'],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_chapeau'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/derb_chapeau'],...
		'position',[785,211,790,216])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/To Workspace7'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/To Workspace7'],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])


%     Subsystem  'UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],'Location',[125,1114771,765,1115016])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/in_1'],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/out_1'],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Calcul t-nT1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Calcul t-nT1'],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Constant4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Sum4'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1',...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial',...
		'position',[175,70,180,75])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],[270,125;290,125])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],[500,115;520,115])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],[430,145;470,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],[275,165;290,165])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],[325,145;360,145])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],[345,145;345,85;470,85])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Subsystem'],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/in_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE/in_2'],...
		'Port','2',...
		'position',[95,250,115,270])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[300,260;370,260])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[130,145;430,145;430,215;450,215])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[365,200;370,200])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[405,230;450,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[490,225;510,225])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[580,225;710,225])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[595,225;595,285;625,285])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[595,225;595,150;630,150])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],[120,260;150,260])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/DERIVEE MESUREE'],...
		'position',[310,260,445,340])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem1/Subsystem/Sum'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/Sum'],...
		'hide name',0,...
		'position',[640,134,665,321])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/out_1'],...
		'position',[465,165,485,185])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/in_1'],...
		'position',[140,190,160,210])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/Subsystem/in_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/in_2'],...
		'Port','2',...
		'position',[180,310,200,330])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/out_2'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/out_2'],...
		'Port','2',...
		'position',[690,145,710,165])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem/out_3'],...
		'Port','3',...
		'position',[470,365,490,385])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[165,200;295,200])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[275,200;190,200;190,280;225,280])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[440,200;580,200;580,180;635,180])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[440,225;455,225;455,250;530,250])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[450,300;530,300])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[670,230;725,230])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[565,275;635,275])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[290,280;305,280])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[440,175;460,175])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[670,230;685,155])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[450,300;465,375])
add_line([sys,'/','UnNamed1/Subsystem1/Subsystem'],[205,320;305,320])
set_param([sys,'/','UnNamed1/Subsystem1/Subsystem'],...
		'Mask Display','Champ rel\n&\nchamp mesur',...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block 'UnNamed1/Subsystem1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem1/Subsystem'],...
		'hide name',0,...
		'position',[260,180,375,230])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Dive non lisse'])
set_param([sys,'/','UnNamed1/Subsystem1/Dive non lisse'],...
		'position',[515,195,520,200])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/mesure'])
set_param([sys,'/','UnNamed1/Subsystem1/mesure'],...
		'position',[515,220,520,225])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie B',13,'axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie B',13,'axes satellite']],...
		'position',[425,150,430,155])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/in_1'],...
		'position',[5,205,25,225])
add_line([sys,'/','UnNamed1/Subsystem1'],[800,220;860,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[800,220;825,220;825,100;880,100])
add_line([sys,'/','UnNamed1/Subsystem1'],[800,265;860,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[835,265;835,135;880,135])
add_line([sys,'/','UnNamed1/Subsystem1'],[800,310;860,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[850,310;850,170;880,170])
add_line([sys,'/','UnNamed1/Subsystem1'],[900,265;960,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[730,265;750,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[30,215;45,215])
add_line([sys,'/','UnNamed1/Subsystem1'],[650,265;660,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[1020,330;1045,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[1115,330;1140,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[1115,330;1115,245;1135,245])
add_line([sys,'/','UnNamed1/Subsystem1'],[220,195;255,195])
add_line([sys,'/','UnNamed1/Subsystem1'],[380,190;430,190;430,390;960,390])
add_line([sys,'/','UnNamed1/Subsystem1'],[380,220;605,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[380,205;405,205;405,310;605,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[220,230;230,230;230,220;255,220])
set_param([sys,'/','UnNamed1/Subsystem1'],...
		'Mask Display','REGULATION PAR\n\nDERIVEE DU CHAMP MAGNETIQUE')


%     Finished composite block 'UnNamed1/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem1'],...
		'hide name',0,...
		'position',[190,174,420,256])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[80,205,100,225])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[125,140,130,145])

add_block('built-in/Note',[sys,'/','UnNamed1/Cette simulation permet de vrifier :'])
set_param([sys,'/','UnNamed1/Cette simulation permet de vrifier :'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[245,390,250,395])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport1'])
set_param([sys,'/','UnNamed1/Inport1'],...
		'hide name',0,...
		'Port','2',...
		'position',[80,305,100,325])

add_block('built-in/Note',[sys,'/',['UnNamed1/Coupure du calcul',13,'couple roue en mode Bpoint']])
set_param([sys,'/',['UnNamed1/Coupure du calcul',13,'couple roue en mode Bpoint']],...
		'ForeGround',1,...
		'position',[305,313,310,318])

add_block('built-in/Product',[sys,'/','UnNamed1/Product'])
set_param([sys,'/','UnNamed1/Product'],...
		'position',[790,279,820,326])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'hide name',0,...
		'Gain','-1',...
		'position',[455,200,500,230])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[545,192,645,238])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'tous les couples']],...
		'position',[725,155,730,160])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain3'])
set_param([sys,'/','UnNamed1/Gain3'],...
		'hide name',0,...
		'position',[695,198,735,232])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[865,295,885,315])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','test4',...
		'buffer','points_trace',...
		'position',[775,362,825,378])
add_line([sys,'/','UnNamed1'],[650,215;690,215])
add_line([sys,'/','UnNamed1'],[505,215;540,215])
add_line([sys,'/','UnNamed1'],[425,215;450,215])
add_line([sys,'/','UnNamed1'],[105,215;185,215])
add_line([sys,'/','UnNamed1'],[105,315;785,315])
add_line([sys,'/','UnNamed1'],[740,215;760,215;760,290;785,290])
add_line([sys,'/','UnNamed1'],[825,305;860,305])
add_line([sys,'/','UnNamed1'],[850,305;850,370;830,370])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','COUPLES POUR\n\nTUMBLING "BPOINT"',...
		'Mask Type','REGULATION "BPOINT" SANS ROUE',...
		'Mask Help','Bloc pris dans reg_derB en "BPOINT"')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[190,188,420,292])


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[307,509,982,814])
open_system([sys,'/','Subsystem5'])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain1'])
set_param([sys,'/','Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[220,170,355,210])

add_block('built-in/Sum',[sys,'/','Subsystem5/Sum1'])
set_param([sys,'/','Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain2'])
set_param([sys,'/','Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])


%     Subsystem  'Subsystem5/Subsystem5'.

new_system([sys,'/','Subsystem5/Subsystem5'])
set_param([sys,'/','Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/Outport',[sys,'/','Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem5/Product'])
set_param([sys,'/','Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Clock',[sys,'/','Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])
add_line([sys,'/','Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','Subsystem5/Subsystem5'],[85,130;115,130])
set_param([sys,'/','Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'Subsystem5/Subsystem5'.

set_param([sys,'/','Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Outport',[sys,'/','Subsystem5/out_1'])
set_param([sys,'/','Subsystem5/out_1'],...
		'position',[575,140,595,160])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace1'])
set_param([sys,'/','Subsystem5/To Workspace1'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','test0',...
		'buffer','points_trace',...
		'position',[430,57,480,73])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/in_1'],...
		'position',[65,100,85,120])
add_line([sys,'/','Subsystem5'],[90,110;185,110])
add_line([sys,'/','Subsystem5'],[90,110;125,110;125,190;215,190])
add_line([sys,'/','Subsystem5'],[480,110;520,110])
add_line([sys,'/','Subsystem5'],[360,190;520,190])
add_line([sys,'/','Subsystem5'],[320,110;335,110])
add_line([sys,'/','Subsystem5'],[550,150;570,150])
add_line([sys,'/','Subsystem5'],[500,110;500,65;485,65])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[565,283,710,337])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[220,770,225,775])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[475,775,480,780])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[780,770,785,775])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'position',[445,327,470,353])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[530,191,1137,462])

add_block('built-in/Note',[sys,'/','Subsystem3/pqr'])
set_param([sys,'/','Subsystem3/pqr'],...
		'ForeGround',1,...
		'position',[190,115,195,120])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/magneto.m1'])
set_param([sys,'/','Subsystem3/magneto.m1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[240,116,375,174])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[30,165,50,185])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',7,...
		'hide name',0,...
		'outputs','[3 4]',...
		'position',[90,118,135,227])

add_block('built-in/Note',[sys,'/','Subsystem3/Q'])
set_param([sys,'/','Subsystem3/Q'],...
		'ForeGround',1,...
		'position',[160,180,165,185])

add_block('built-in/Note',[sys,'/','Subsystem3/Q non utilis'])
set_param([sys,'/','Subsystem3/Q non utilis'],...
		'ForeGround',1,...
		'position',[180,210,185,215])

add_block('built-in/Outport',[sys,'/','Subsystem3/out_2'])
set_param([sys,'/','Subsystem3/out_2'],...
		'ForeGround',1,...
		'BackGround',7,...
		'position',[450,135,470,155])

add_block('built-in/Note',[sys,'/',['Subsystem3/Second membre des quations du TMC',13,'avec les termes de couplage et le rle ',13,'de la roue']])
set_param([sys,'/',['Subsystem3/Second membre des quations du TMC',13,'avec les termes de couplage et le rle ',13,'de la roue']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[290,30,295,35])
add_line([sys,'/','Subsystem3'],[380,145;445,145])
add_line([sys,'/','Subsystem3'],[140,145;235,145])
add_line([sys,'/','Subsystem3'],[55,175;85,175])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','F(X,t)\n\nPOUR LA ROTATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,589,415,661])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,930,345])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,697,415,763])


%     Subsystem  ['Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1']],'Location',[4,166,1267,899])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inport']],...
		'position',[10,485,30,505])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'ForeGround',1)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',18)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[400,35,405,40])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/B']],...
		'position',[480,425,485,430])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[110,515,115,520])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[770,382,805,408])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[850,399,855,404])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[660,277,665,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[740,438,800,472])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[345,315,460,365])

add_block('built-in/To Workspace',[sys,'/',['Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[865,440,985,470])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[215,246,220,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[610,378,670,412])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[510,286,555,504])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[290,288,320,392])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[100,293,245,317])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[100,328,245,352])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[100,363,245,387])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/M']],...
		'position',[495,315,500,320])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[755,318,900,342])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[755,283,900,307])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[755,248,900,272])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[945,243,975,347])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,195,870,200])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[765,158,910,182])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[765,123,910,147])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[765,88,910,112])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[955,83,985,187])


%     Subsystem  ['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[231,269,1077,738])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'position',[190,95,365,145])

add_block('built-in/Clock',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[120,104,155,136])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[280,70,285,75])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/En axes satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/En axes satellite']],...
		'position',[730,220,735,225])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[125,205,130,210])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[145,65,150,70])

add_block('built-in/To Workspace',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']],...
		'hide name',0,...
		'mat-name','BY',...
		'buffer','points_trace',...
		'position',[515,32,565,48])

add_block('built-in/Demux',[sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux']],...
		'outputs','3',...
		'position',[440,24,480,56])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[370,120;480,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[160,120;185,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[395,120;395,40;435,40])
add_line([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[485,40;510,40])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[210,458,410,532])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3',...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'position',[600,554,775,606])

add_block('built-in/Sum',[sys,'/',['Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1055,254,1090,361])

add_block('built-in/State-Space',[sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'ForeGround',1,...
		'BackGround',3,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'Mask Type','Matrix Gain',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Inverse matrice',13,'satellite']],...
		'position',[1125,288,1195,332])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1225,300,1245,320])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[635,505,640,510])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[695,605,700,610])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[780,580;1020,580;1020,345;1050,345])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[35,495;205,495])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[45,495;45,580;595,580])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[990,135;1040,135;1050,270])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,330;940,330])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[980,295;1050,295])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,295;940,295])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[905,260;940,260])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,170;950,170])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,135;950,135])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[915,100;950,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,375;285,375])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,340;285,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[250,305;285,305])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[325,340;340,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[465,340;505,340])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[415,495;440,495;440,450;505,450])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[560,395;605,395])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[805,455;860,455])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[675,395;705,395;705,455;735,455])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[705,395;765,395])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[810,395;1005,400;1005,320;1050,320])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[1095,310;1120,310])
add_line([sys,'/',['Perturbations',13,'arodynamiques1']],[1200,310;1220,310])
set_param([sys,'/',['Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['Perturbations',13,'arodynamiques1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[180,510,415,570])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[90,50,975,400])

add_block('built-in/Note',[sys,'/','Subsystem4/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'])
set_param([sys,'/','Subsystem4/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'],...
		'ForeGround',3,...
		'BackGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[530,50,535,55])

add_block('built-in/Note',[sys,'/',['Subsystem4/Sortie du couplage',13,'roue satellite']])
set_param([sys,'/',['Subsystem4/Sortie du couplage',13,'roue satellite']],...
		'position',[715,205,720,210])

add_block('built-in/Note',[sys,'/','Subsystem4/Fonction jw_rotot.m'])
set_param([sys,'/','Subsystem4/Fonction jw_rotot.m'],...
		'position',[495,215,500,220])

add_block('built-in/Note',[sys,'/','Subsystem4/pqrQ'])
set_param([sys,'/','Subsystem4/pqrQ'],...
		'position',[200,195,205,200])

add_block('built-in/Note',[sys,'/','Subsystem4/Vitesseroue'])
set_param([sys,'/','Subsystem4/Vitesseroue'],...
		'position',[195,125,200,130])

add_block('built-in/Mux',[sys,'/','Subsystem4/Mux'])
set_param([sys,'/','Subsystem4/Mux'],...
		'inputs','[1 7]',...
		'position',[285,108,340,252])

add_block('built-in/Inport',[sys,'/','Subsystem4/in_1'])
set_param([sys,'/','Subsystem4/in_1'],...
		'position',[235,135,255,155])

add_block('built-in/Inport',[sys,'/','Subsystem4/in_2'])
set_param([sys,'/','Subsystem4/in_2'],...
		'Port','2',...
		'position',[235,205,255,225])

add_block('built-in/Outport',[sys,'/','Subsystem4/out_1'])
set_param([sys,'/','Subsystem4/out_1'],...
		'position',[680,170,700,190])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem4/magneto.m2'])
set_param([sys,'/','Subsystem4/magneto.m2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue\nau second membre')
set_param([sys,'/','Subsystem4/magneto.m2'],...
		'position',[415,156,555,204])

add_block('built-in/Gain',[sys,'/','Subsystem4/Gain1'])
set_param([sys,'/','Subsystem4/Gain1'],...
		'hide name',0,...
		'position',[600,167,625,193])
add_line([sys,'/','Subsystem4'],[345,180;410,180])
add_line([sys,'/','Subsystem4'],[260,145;280,145])
add_line([sys,'/','Subsystem4'],[260,215;280,215])
add_line([sys,'/','Subsystem4'],[560,180;595,180])
add_line([sys,'/','Subsystem4'],[630,180;675,180])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','COUPLAGE ROUE-SATELLITE')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[175,442,415,498])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[610,410,630,670])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[745,276,760,414])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[755,410,760,415])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[820,215,855,675])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[750,605,755,610])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[805,530,810,535])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,83,1267,980])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[900,565,905,570])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[860,370,930,390])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[410,455,415,460])

add_block('built-in/To File',[sys,'/','Subsystem/To File4'])
set_param([sys,'/','Subsystem/To File4'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'File name','initpqrQ.mat',...
		'Matrix name','initpqrQ',...
		'position',[180,357,335,413])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[985,624,1070,656])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[885,621,965,659])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn5'])
set_param([sys,'/','Subsystem/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[1000,731,1080,769])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace18'])
set_param([sys,'/','Subsystem/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie_relative',...
		'buffer','points_trace',...
		'position',[1100,737,1235,763])


%     Subsystem  ['Subsystem/ANGLES',13,'EN DEGRES'].

new_system([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/x']])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],[90,65;125,65])
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'Mask Entries','6000\/-200\/200\/''y-/m--/c-./w+''\/')


%     Finished composite block ['Subsystem/ANGLES',13,'EN DEGRES'].

set_param([sys,'/',['Subsystem/ANGLES',13,'EN DEGRES']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[615,742,705,798])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','initpqrQ_final',...
		'buffer','1',...
		'position',[315,292,405,318])


%     Subsystem  'Subsystem/Subsystem'.

new_system([sys,'/','Subsystem/Subsystem'])
set_param([sys,'/','Subsystem/Subsystem'],'Location',[15,6553670,530,6553965])

add_block('built-in/Note',[sys,'/',['Subsystem/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']])
set_param([sys,'/',['Subsystem/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[255,35,260,40])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem/Constant'])
set_param([sys,'/','Subsystem/Subsystem/Constant'],...
		'hide name',0,...
		'Value','vitesse_angul_mini',...
		'position',[80,104,215,126])

add_block('built-in/Constant',[sys,'/','Subsystem/Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Subsystem/Constant1'],...
		'hide name',0,...
		'Value','vitesse_angul_mini0',...
		'position',[80,139,215,161])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Subsystem/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem/Subsystem/Relational',13,'Operator']],...
		'hide name',0,...
		'Operator','<=',...
		'position',[265,96,290,169])

add_block('built-in/Product',[sys,'/','Subsystem/Subsystem/Product'])
set_param([sys,'/','Subsystem/Subsystem/Product'],...
		'hide name',0,...
		'position',[335,110,360,205])

add_block('built-in/To File',[sys,'/','Subsystem/Subsystem/To File4'])
set_param([sys,'/','Subsystem/Subsystem/To File4'],...
		'hide name',0,...
		'File name','B_point.mat',...
		'Matrix name','temps_Bpoint',...
		'position',[395,137,485,183])

add_block('built-in/Clock',[sys,'/','Subsystem/Subsystem/Clock1'])
set_param([sys,'/','Subsystem/Subsystem/Clock1'],...
		'hide name',0,...
		'position',[80,203,140,257])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[160,180,230,200])
add_line([sys,'/','Subsystem/Subsystem'],[365,160;390,160])
add_line([sys,'/','Subsystem/Subsystem'],[145,230;245,230;245,180;330,180])
add_line([sys,'/','Subsystem/Subsystem'],[295,135;330,135])
add_line([sys,'/','Subsystem/Subsystem'],[220,150;260,150])
add_line([sys,'/','Subsystem/Subsystem'],[220,115;260,115])
add_line([sys,'/','Subsystem/Subsystem'],[145,230;155,190])
set_param([sys,'/','Subsystem/Subsystem'],...
		'Mask Display','TEMPS B_POINT')


%     Finished composite block 'Subsystem/Subsystem'.

set_param([sys,'/','Subsystem/Subsystem'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[170,525,390,584])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;855,380])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;880,640])
add_line([sys,'/','Subsystem'],[970,640;980,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[1085,750;1095,750])
add_line([sys,'/','Subsystem'],[970,640;970,750;995,750])
add_line([sys,'/','Subsystem'],[440,425;440,385;340,385])
add_line([sys,'/','Subsystem'],[830,465;830,770;710,770])
add_line([sys,'/','Subsystem'],[435,385;435,305;410,305])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES\n\nENERGIE\n\n& TRANSFERT DE initpqrQ')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'ForeGround',6,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[1060,259,1265,361])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[980,260,985,265])


%     Subsystem  'Stops'.

new_system([sys,'/','Stops'])
set_param([sys,'/','Stops'],'Location',[64,144,884,669])

add_block('built-in/Inport',[sys,'/','Stops/in_1'])
set_param([sys,'/','Stops/in_1'],...
		'position',[75,225,95,245])


%     Subsystem  'Stops/Stop detumbling2'.

new_system([sys,'/','Stops/Stop detumbling2'])
set_param([sys,'/','Stops/Stop detumbling2'],'Location',[769,541,1204,644])

add_block('built-in/Inport',[sys,'/','Stops/Stop detumbling2/in_1'])
set_param([sys,'/','Stops/Stop detumbling2/in_1'],...
		'position',[130,55,150,75])

add_block('built-in/Gain',[sys,'/','Stops/Stop detumbling2/Gain'])
set_param([sys,'/','Stops/Stop detumbling2/Gain'],...
		'BackGround',7,...
		'position',[230,48,310,82])

add_block('built-in/Stop Simulation',[sys,'/','Stops/Stop detumbling2/Stop Simulation'])
set_param([sys,'/','Stops/Stop detumbling2/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Note',[sys,'/','Stops/Stop detumbling2/Stop dsamorable'])
set_param([sys,'/','Stops/Stop detumbling2/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])
add_line([sys,'/','Stops/Stop detumbling2'],[155,65;225,65])
add_line([sys,'/','Stops/Stop detumbling2'],[315,65;345,65])
set_param([sys,'/','Stops/Stop detumbling2'],...
		'Mask Display','STOP DU MODE FIN\n\nDESAMORCABLE')


%     Finished composite block 'Stops/Stop detumbling2'.

set_param([sys,'/','Stops/Stop detumbling2'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[605,162,770,208])

add_block('built-in/Constant',[sys,'/','Stops/Constant2'])
set_param([sys,'/','Stops/Constant2'],...
		'Value','angle_mini_mod_fin',...
		'position',[270,134,440,156])

add_block('built-in/Demux',[sys,'/','Stops/Demux1'])
set_param([sys,'/','Stops/Demux1'],...
		'outputs','[3 3]',...
		'position',[240,207,280,263])

add_block('built-in/MATLAB Fcn',[sys,'/','Stops/fpqrQ_V_P1'])
set_param([sys,'/','Stops/fpqrQ_V_P1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'Mask Display','pqrQ_V_P',...
		'position',[125,214,195,256])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops/Valeur absolue',13,'des angles1']])
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil angulaire',...
		'position',[335,196,430,244])


%     Subsystem  'Stops/Stop detumbling3'.

new_system([sys,'/','Stops/Stop detumbling3'])
set_param([sys,'/','Stops/Stop detumbling3'],'Location',[724,654,1159,757])

add_block('built-in/Inport',[sys,'/','Stops/Stop detumbling3/in_1'])
set_param([sys,'/','Stops/Stop detumbling3/in_1'],...
		'position',[130,55,150,75])

add_block('built-in/Gain',[sys,'/','Stops/Stop detumbling3/Gain'])
set_param([sys,'/','Stops/Stop detumbling3/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[230,48,310,82])

add_block('built-in/Stop Simulation',[sys,'/','Stops/Stop detumbling3/Stop Simulation'])
set_param([sys,'/','Stops/Stop detumbling3/Stop Simulation'],...
		'position',[350,43,400,87])

add_block('built-in/Note',[sys,'/','Stops/Stop detumbling3/Stop dsamorable'])
set_param([sys,'/','Stops/Stop detumbling3/Stop dsamorable'],...
		'ForeGround',1,...
		'position',[235,95,240,100])
add_line([sys,'/','Stops/Stop detumbling3'],[155,65;225,65])
add_line([sys,'/','Stops/Stop detumbling3'],[315,65;345,65])
set_param([sys,'/','Stops/Stop detumbling3'],...
		'Mask Display','STOP DU MODE FIN\n\nDESAMORCABLE')


%     Finished composite block 'Stops/Stop detumbling3'.

set_param([sys,'/','Stops/Stop detumbling3'],...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[605,357,770,403])

add_block('built-in/MATLAB Fcn',[sys,'/',['Stops/Valeur absolue',13,'des angles2']])
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'Mask Display','Stop\nseuil  vitesse angulaire')
set_param([sys,'/',['Stops/Valeur absolue',13,'des angles2']],...
		'position',[330,390,465,440])

add_block('built-in/Constant',[sys,'/','Stops/Constant3'])
set_param([sys,'/','Stops/Constant3'],...
		'Value','vitesse_angul_mini',...
		'position',[310,329,480,351])

add_block('built-in/Relational Operator',[sys,'/',['Stops/Relational',13,'Operator1']])
set_param([sys,'/',['Stops/Relational',13,'Operator1']],...
		'position',[505,108,545,257])

add_block('built-in/Relational Operator',[sys,'/',['Stops/Relational',13,'Operator2']])
set_param([sys,'/',['Stops/Relational',13,'Operator2']],...
		'position',[510,303,550,452])

add_block('built-in/Note',[sys,'/','Stops/La'])
set_param([sys,'/','Stops/La'],...
		'position',[205,65,210,70])

add_block('built-in/Note',[sys,'/','Stops/Contrle du seuil angulaire'])
set_param([sys,'/','Stops/Contrle du seuil angulaire'],...
		'ForeGround',1,...
		'position',[680,215,685,220])

add_block('built-in/Note',[sys,'/','Stops/Contrle du seuil de vitesse'])
set_param([sys,'/','Stops/Contrle du seuil de vitesse'],...
		'ForeGround',1,...
		'position',[690,405,695,410])

add_block('built-in/Note',[sys,'/',['Stops/CONTROLEURS DE DEROULEMENT ',13,'']])
set_param([sys,'/',['Stops/CONTROLEURS DE DEROULEMENT ',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[415,25,420,30])
add_line([sys,'/','Stops'],[100,235;120,235])
add_line([sys,'/','Stops'],[200,235;235,235])
add_line([sys,'/','Stops'],[550,185;600,185])
add_line([sys,'/','Stops'],[445,145;500,145])
add_line([sys,'/','Stops'],[435,220;500,220])
add_line([sys,'/','Stops'],[285,220;330,220])
add_line([sys,'/','Stops'],[285,250;300,250;300,415;325,415])
add_line([sys,'/','Stops'],[555,380;600,380])
add_line([sys,'/','Stops'],[470,415;505,415])
add_line([sys,'/','Stops'],[485,340;505,340])
set_param([sys,'/','Stops'],...
		'Mask Display','STOP DE SIMULATION\nSUR SEUIL ANGULAIRE\n( angle mini_mod_fin )')


%     Finished composite block 'Stops'.

set_param([sys,'/','Stops'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'position',[1050,388,1260,442])


%     Subsystem  'Graphes'.

new_system([sys,'/','Graphes'])
set_param([sys,'/','Graphes'],'Location',[42,91,1182,676])
open_system([sys,'/','Graphes'])


%     Subsystem  'Graphes/Extras27'.

new_system([sys,'/','Graphes/Extras27'])
set_param([sys,'/','Graphes/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras27'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r,temps,switch_long/10);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras27'.

set_param([sys,'/','Graphes/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[15,240,220,301])


%     Subsystem  'Graphes/Extras22'.

new_system([sys,'/','Graphes/Extras22'])
set_param([sys,'/','Graphes/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras22'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras22'.

set_param([sys,'/','Graphes/Extras22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,310,225,371])


%     Subsystem  'Graphes/Extras29'.

new_system([sys,'/','Graphes/Extras29'])
set_param([sys,'/','Graphes/Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras29'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras29'.

set_param([sys,'/','Graphes/Extras29'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[250,325,480,381])


%     Subsystem  'Graphes/Extras21'.

new_system([sys,'/','Graphes/Extras21'])
set_param([sys,'/','Graphes/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras21'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras21'.

set_param([sys,'/','Graphes/Extras21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,235,710,301])


%     Subsystem  'Graphes/Extras20'.

new_system([sys,'/','Graphes/Extras20'])
set_param([sys,'/','Graphes/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras20'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras20'.

set_param([sys,'/','Graphes/Extras20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[510,315,710,381])


%     Subsystem  'Graphes/Extras30'.

new_system([sys,'/','Graphes/Extras30'])
set_param([sys,'/','Graphes/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras30'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras30'.

set_param([sys,'/','Graphes/Extras30'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[515,160,710,216])


%     Subsystem  'Graphes/Extras34'.

new_system([sys,'/','Graphes/Extras34'])
set_param([sys,'/','Graphes/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras34'],...
		'Mask Display','Voir courbe\nchangement\nde rgulation',...
		'Mask Dialogue','eval(''plot(temps,switch_long);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras34'.

set_param([sys,'/','Graphes/Extras34'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,315,1100,381])


%     Subsystem  'Graphes/Extras32'.

new_system([sys,'/','Graphes/Extras32'])
set_param([sys,'/','Graphes/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras32'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras32'.

set_param([sys,'/','Graphes/Extras32'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,235,1100,301])


%     Subsystem  'Graphes/Extras23'.

new_system([sys,'/','Graphes/Extras23'])
set_param([sys,'/','Graphes/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras23'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet,temps,switch_long*100);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras23'.

set_param([sys,'/','Graphes/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[20,155,220,221])


%     Subsystem  'Graphes/Extras24'.

new_system([sys,'/','Graphes/Extras24'])
set_param([sys,'/','Graphes/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras24'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras24'.

set_param([sys,'/','Graphes/Extras24'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,165,910,231])


%     Subsystem  'Graphes/Extras25'.

new_system([sys,'/','Graphes/Extras25'])
set_param([sys,'/','Graphes/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras25'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras25'.

set_param([sys,'/','Graphes/Extras25'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,240,910,306])


%     Subsystem  'Graphes/Extras26'.

new_system([sys,'/','Graphes/Extras26'])
set_param([sys,'/','Graphes/Extras26'],'Location',[4,50,1012,686])
set_param([sys,'/','Graphes/Extras26'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Graphes/Extras26'.

set_param([sys,'/','Graphes/Extras26'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,225,475,311])


%     Subsystem  'Graphes/Extras28'.

new_system([sys,'/','Graphes/Extras28'])
set_param([sys,'/','Graphes/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras28'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx_deriv, my_deriv, mz_deriv')
set_param([sys,'/','Graphes/Extras28'],...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv,temps,switch_long*0.2);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras28'.

set_param([sys,'/','Graphes/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[240,155,490,216])


%     Subsystem  'Graphes/Extras31'.

new_system([sys,'/','Graphes/Extras31'])
set_param([sys,'/','Graphes/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras31'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue,temps,switch_long*4e-6);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras31'.

set_param([sys,'/','Graphes/Extras31'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[925,160,1100,226])


%     Subsystem  'Graphes/Extras33'.

new_system([sys,'/','Graphes/Extras33'])
set_param([sys,'/','Graphes/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras33'],...
		'Mask Display','Voir courbe\ncomposantes\n\n By et BY du champ',...
		'Mask Dialogue','eval(''plot(temps,BY,temps,By);grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras33'.

set_param([sys,'/','Graphes/Extras33'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[735,310,905,386])

add_block('built-in/Note',[sys,'/','Graphes/SORTIES GRAPHIQUES'])
set_param([sys,'/','Graphes/SORTIES GRAPHIQUES'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[535,25,540,30])

add_block('built-in/Note',[sys,'/','Graphes/Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Graphes/Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[545,85,550,90])


%     Subsystem  'Graphes/Extras35'.

new_system([sys,'/','Graphes/Extras35'])
set_param([sys,'/','Graphes/Extras35'],'Location',[4,42,1012,678])
set_param([sys,'/','Graphes/Extras35'],...
		'Mask Display','Evolutions test_basculement\n\nswitch_long( x -1)',...
		'Mask Dialogue','eval(''plot(temps,test_basculement,temps,switch_long*(-1));grid;figure(gcf)'')')


%     Finished composite block 'Graphes/Extras35'.

set_param([sys,'/','Graphes/Extras35'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[885,485,1120,551])
set_param([sys,'/','Graphes'],...
		'Mask Display','SORTIES\n\nGRAPHIQUES')


%     Finished composite block 'Graphes'.

set_param([sys,'/','Graphes'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[1050,575,1265,651])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','INITIALISATION\n(puldatP.m)\n par double clic souris\nCAS PULSE',...
		'Mask Dialogue','eval(''puldatP'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1055,675,1270,766])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[920,588,955,622])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[8,66,1236,792])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou janvier 2014'])
set_param([sys,'/','Subsystem1/Robert Guiziou janvier 2014'],...
		'ForeGround',2,...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est totale1.m']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est totale1.m']],...
		'Font Size',14,...
		'position',[405,125,410,130])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,90,500,95])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes totdatNP ( sans pulse ) ou totdatP ( avec pulse ) '])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes totdatNP ( sans pulse ) ou totdatP ( avec pulse ) '],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[680,210,685,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 4000  100000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 4000  100000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[565,235,570,240])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[305,265,310,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop ( paramtrable ) arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop ( paramtrable ) arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[530,295,535,300])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans la boite SORTIES GRAPHIQUES qui prsente les sorties au choix'])
set_param([sys,'/','Subsystem1/a) En cliquant dans la boite SORTIES GRAPHIQUES qui prsente les sorties au choix'],...
		'Font Size',14,...
		'position',[550,400,555,405])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[335,365,340,370])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[550,515,555,520])

add_block('built-in/Note',[sys,'/','Subsystem1/5 - SYNTHESE DES RESULTATS :      Cliquer sur '])
set_param([sys,'/','Subsystem1/5 - SYNTHESE DES RESULTATS :      Cliquer sur '],...
		'ForeGround',5,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[375,610,380,615])

add_block('built-in/Note',[sys,'/','Subsystem1/RETROUVER LES CARACTERISTIQUES MISSION'])
set_param([sys,'/','Subsystem1/RETROUVER LES CARACTERISTIQUES MISSION'],...
		'ForeGround',5,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[920,610,925,615])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[875,825,1225,866])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','RETROUVER LES PRINCIPALES CARACTERISTIQUES DANS L''ESPACE MATLAB',...
		'Mask Dialogue','eval(''display'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[145,815,830,851])

add_block('built-in/Note',[sys,'/',['STABILISATION TOTALE DU LANCEMENT AUX PREMIERES PHOTOS',13,'PHASE DE DETUMBLING JUSQU''A L''ACQUISITION FINE']])
set_param([sys,'/',['STABILISATION TOTALE DU LANCEMENT AUX PREMIERES PHOTOS',13,'PHASE DE DETUMBLING JUSQU''A L''ACQUISITION FINE']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[703,5,708,10])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE  ET DE DEUX TYPES DE REGULATION',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE  ET DE DEUX TYPES DE REGULATION',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[685,90,690,95])

add_block('built-in/Note',[sys,'/','CHAMP MAGNETIQUE REEL ( Sans tenir compte de la copntrainte de la mesure )'])
set_param([sys,'/','CHAMP MAGNETIQUE REEL ( Sans tenir compte de la copntrainte de la mesure )'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[655,135,660,140])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\n(puldatNP.m)\n par double clic souris\nCAS NON PULSE',...
		'Mask Dialogue','eval(''puldatNP'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1050,460,1265,551])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[98,234,990,830])
open_system([sys,'/','Subsystem2'])

add_block('built-in/Note',[sys,'/',['Subsystem2/SEQUENCEUR FAISANT BASCULER DU MODE "BPOINT"',13,' AU MODE ACQUISITION GROSSIERE PUIS FINE',13,'SUR DETECTION D''UN SEUIL DE VITESSE']])
set_param([sys,'/',['Subsystem2/SEQUENCEUR FAISANT BASCULER DU MODE "BPOINT"',13,' AU MODE ACQUISITION GROSSIERE PUIS FINE',13,'SUR DETECTION D''UN SEUIL DE VITESSE']],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['Subsystem2/SEQUENCEUR FAISANT BASCULER DU MODE "BPOINT"',13,' AU MODE ACQUISITION GROSSIERE PUIS FINE',13,'SUR DETECTION D''UN SEUIL DE VITESSE']],...
		'Font Size',16,...
		'position',[520,25,525,30])

add_block('built-in/Note',[sys,'/','Subsystem2/NB : La mise  1 du stop permet de ne raliser que la rduction des vitesses en "Bpoint'])
set_param([sys,'/','Subsystem2/NB : La mise  1 du stop permet de ne raliser que la rduction des vitesses en "Bpoint'],...
		'ForeGround',1,...
		'position',[615,0,620,5])

add_block('built-in/Note',[sys,'/',['Subsystem2/La mise  1 su stop permet de n''effectuer que la rgulation en "BPOINT"',13,'']])
set_param([sys,'/',['Subsystem2/La mise  1 su stop permet de n''effectuer que la rgulation en "BPOINT"',13,'']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'position',[500,100,505,105])

add_block('built-in/Note',[sys,'/','Subsystem2/Sortie du switch1 ( valeur 1 ou 0)'])
set_param([sys,'/','Subsystem2/Sortie du switch1 ( valeur 1 ou 0)'],...
		'ForeGround',1,...
		'position',[700,260,705,265])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[510,504,515,509])

add_block('built-in/Note',[sys,'/',['Subsystem2/1 si w > vitesse_angul_mini',13,'0 si w < =vitesse_angul_mini',13,'',13,'K_tumbling vaut en mode Bpoint',13,'et 0 en mode acquisition']])
set_param([sys,'/',['Subsystem2/1 si w > vitesse_angul_mini',13,'0 si w < =vitesse_angul_mini',13,'',13,'K_tumbling vaut en mode Bpoint',13,'et 0 en mode acquisition']],...
		'ForeGround',7,...
		'Font Name','Arial')
set_param([sys,'/',['Subsystem2/1 si w > vitesse_angul_mini',13,'0 si w < =vitesse_angul_mini',13,'',13,'K_tumbling vaut en mode Bpoint',13,'et 0 en mode acquisition']],...
		'position',[220,195,225,200])

add_block('built-in/Constant',[sys,'/','Subsystem2/Constant'])
set_param([sys,'/','Subsystem2/Constant'],...
		'position',[470,450,490,470])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[735,421,790,479])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation1'])
set_param([sys,'/','Subsystem2/Stop Simulation1'],...
		'position',[385,396,440,454])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt1']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'Mask Display','Stop rduction\nvitesses')
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt1']],...
		'position',[245,404,340,446])

add_block('built-in/Sum',[sys,'/','Subsystem2/Sum'])
set_param([sys,'/','Subsystem2/Sum'],...
		'inputs','-+',...
		'position',[525,424,555,471])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[615,433,695,467])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[160,305,180,325])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace13'])
set_param([sys,'/','Subsystem2/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','switch1',...
		'buffer','1',...
		'position',[505,257,600,293])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'MATLAB Fcn','stoptumb(u)',...
		'Output Width','1',...
		'Mask Display','Stop\ndetumbling')
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'position',[250,294,320,336])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace12'])
set_param([sys,'/','Subsystem2/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','K_tumbling',...
		'buffer','1',...
		'position',[360,257,455,293])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem2/MATLAB Fcn'])
set_param([sys,'/','Subsystem2/MATLAB Fcn'],...
		'MATLAB Fcn','souvenir(u)',...
		'Output Width','1',...
		'position',[380,298,440,332])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/out_1'],...
		'position',[620,305,640,325])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace14'])
set_param([sys,'/','Subsystem2/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','switch_long',...
		'buffer','points_trace',...
		'position',[510,352,605,388])


%     Subsystem  'Subsystem2/Subsystem'.

new_system([sys,'/','Subsystem2/Subsystem'])
set_param([sys,'/','Subsystem2/Subsystem'],'Location',[15,70,530,365])

add_block('built-in/Note',[sys,'/',['Subsystem2/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']])
set_param([sys,'/',['Subsystem2/Subsystem/Fonction servant au calcul',13,'de la dure de B_POINT']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[255,35,260,40])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem2/Subsystem/Relational',13,'Operator']])
set_param([sys,'/',['Subsystem2/Subsystem/Relational',13,'Operator']],...
		'hide name',0,...
		'Operator','<=',...
		'position',[265,96,290,169])

add_block('built-in/Product',[sys,'/','Subsystem2/Subsystem/Product'])
set_param([sys,'/','Subsystem2/Subsystem/Product'],...
		'hide name',0,...
		'position',[335,110,360,205])

add_block('built-in/To File',[sys,'/','Subsystem2/Subsystem/To File4'])
set_param([sys,'/','Subsystem2/Subsystem/To File4'],...
		'hide name',0,...
		'File name','B_point.mat',...
		'Matrix name','temps_Bpoint',...
		'position',[395,137,485,183])

add_block('built-in/Clock',[sys,'/','Subsystem2/Subsystem/Clock1'])
set_param([sys,'/','Subsystem2/Subsystem/Clock1'],...
		'hide name',0,...
		'position',[80,203,140,257])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem2/Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[160,180,230,200])

add_block('built-in/Inport',[sys,'/','Subsystem2/Subsystem/in_1'])
set_param([sys,'/','Subsystem2/Subsystem/in_1'],...
		'position',[155,140,175,160])

add_block('built-in/Constant',[sys,'/','Subsystem2/Subsystem/Constant'])
set_param([sys,'/','Subsystem2/Subsystem/Constant'],...
		'position',[150,104,220,126])
add_line([sys,'/','Subsystem2/Subsystem'],[365,160;390,160])
add_line([sys,'/','Subsystem2/Subsystem'],[145,230;245,230;245,180;330,180])
add_line([sys,'/','Subsystem2/Subsystem'],[295,135;330,135])
add_line([sys,'/','Subsystem2/Subsystem'],[145,230;155,190])
add_line([sys,'/','Subsystem2/Subsystem'],[225,115;260,115])
add_line([sys,'/','Subsystem2/Subsystem'],[180,150;260,150])
set_param([sys,'/','Subsystem2/Subsystem'],...
		'Mask Display','TEMPS B_POINT')


%     Finished composite block 'Subsystem2/Subsystem'.

set_param([sys,'/','Subsystem2/Subsystem'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[500,200,615,240])
add_line([sys,'/','Subsystem2'],[445,315;615,315])
add_line([sys,'/','Subsystem2'],[445,315;470,315;470,275;500,275])
add_line([sys,'/','Subsystem2'],[325,315;335,315;335,275;355,275])
add_line([sys,'/','Subsystem2'],[335,315;375,315])
add_line([sys,'/','Subsystem2'],[185,315;245,315])
add_line([sys,'/','Subsystem2'],[470,315;470,370;505,370])
add_line([sys,'/','Subsystem2'],[185,315;185,425;240,425])
add_line([sys,'/','Subsystem2'],[700,450;730,450])
add_line([sys,'/','Subsystem2'],[345,425;380,425])
add_line([sys,'/','Subsystem2'],[560,450;610,450])
add_line([sys,'/','Subsystem2'],[495,460;520,460])
add_line([sys,'/','Subsystem2'],[470,365;470,435;520,435])
add_line([sys,'/','Subsystem2'],[470,275;470,220;495,220])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','SWITCH1\nBpoint\nvers\nAcquisition')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'position',[30,261,135,359])
add_line(sys,[860,445;895,445])
add_line(sys,[875,445;875,335;1055,335])
add_line(sys,[140,310;485,310])
add_line(sys,[425,240;430,240])
add_line(sys,[465,240;465,280;485,280])
add_line(sys,[430,340;440,340])
add_line(sys,[1005,445;1015,445;1015,775;15,775;15,215;185,215])
add_line(sys,[420,730;660,730;660,560;815,560])
add_line(sys,[475,340;485,340])
add_line(sys,[15,310;25,310])
add_line(sys,[635,540;690,540;690,380;740,380])
add_line(sys,[715,310;740,310])
add_line(sys,[530,310;560,310])
add_line(sys,[1005,445;1015,445;1015,285;1055,285])
add_line(sys,[1015,415;1045,415])
add_line(sys,[15,385;185,385])
add_line(sys,[140,310;170,340;185,340])
add_line(sys,[140,310;170,265;185,265])
add_line(sys,[15,730;175,730])
add_line(sys,[15,625;175,625])
add_line(sys,[15,540;175,540])
add_line(sys,[430,385;445,385;445,425;155,425;155,455;170,455])
add_line(sys,[15,485;170,485])
add_line(sys,[420,625;605,625])
add_line(sys,[420,540;605,540])
add_line(sys,[420,470;560,470;560,455;605,455])
add_line(sys,[765,345;790,345;790,330;815,330])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
